(herald "Four Party Needham-Schroeder-Lowe Protocol")

(comment "CPSA 2.3.1")
(comment "All input read from nsl4cm1.lsp")

(defprotocol nsl4cm basic
  (defrole init
    (vars (a b c d name) (na nb nc nd text))
    (trace (send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b)))))
  (defrole resp1
    (vars (a b c d name) (na nb nc nd text))
    (trace (recv (enc a c d na (pubk b)))
      (send (enc a b d na nb (pubk c))) (recv (enc nb nc nd (pubk b)))
      (send (enc nc nd (pubk c)))))
  (defrole resp2
    (vars (a b c d name) (na nb nc nd text))
    (trace (recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))) (recv (enc nc nd (pubk c)))
      (send (enc nd (pubk d)))))
  (defrole resp3
    (vars (a b c d name) (na nb nc nd text))
    (trace (recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a)))
      (recv (enc nd (pubk d))))))

(defskeleton nsl4cm
  (vars (na nb nc nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b)))))
  (label 0)
  (unrealized (0 1))
  (origs (na (0 0)))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (0 1)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-0 (pubk c)))))
  (label 1)
  (parent 0)
  (unrealized (0 1))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (0 1)) ((2 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (0 1)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 2)
  (parent 1)
  (unrealized (0 1) (2 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 3 1 resp1 2) na (2 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 3)
  (parent 2)
  (unrealized (0 1))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (2 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 4)
  (parent 2)
  (seen 3)
  (unrealized (0 1) (2 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 5)
  (parent 3)
  (unrealized (0 1) (3 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 6)
  (parent 3)
  (unrealized (0 1) (3 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (2 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 7)
  (parent 4)
  (unrealized (0 1) (2 0) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 4 1 resp1 2) nb-0 (3 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d)))))
  (label 8)
  (parent 5)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 4 1 resp1 2) na (3 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 9)
  (parent 6)
  (unrealized (0 1) (3 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (3 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 10)
  (parent 6)
  (seen 17)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 5 1 resp1 2) na (4 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 11)
  (parent 7)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 5 3 resp1 2) na (4 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 12)
  (parent 7)
  (unrealized (0 1) (2 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (4 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 13)
  (parent 7)
  (seen 12)
  (unrealized (0 1) (2 0) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 14)
  (parent 8)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 15)
  (parent 8)
  (unrealized (0 1) (3 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 16)
  (parent 8)
  (unrealized (0 1) (3 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 4 2 resp2 2) na (3 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 17)
  (parent 9)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (3 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 18)
  (parent 9)
  (unrealized (0 1) (3 0) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) na (3 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 19)
  (parent 10)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (3 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 20)
  (parent 10)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 5 3 resp1 2) na (4 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 21)
  (parent 11)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (4 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 22)
  (parent 11)
  (unrealized (0 1) (4 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 5 1 resp1 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 23)
  (parent 12)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 24)
  (parent 12)
  (unrealized (0 1) (2 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 25)
  (parent 12)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) na (4 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 26)
  (parent 13)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (4 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 27)
  (parent 13)
  (unrealized (0 1) (2 0) (4 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 28)
  (parent 14)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 29)
  (parent 14)
  (seen 33)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 30)
  (parent 14)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 31)
  (parent 14)
  (seen 35)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 4 1 resp1 2) nb-0 (3 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 32)
  (parent 15)
  (seen 74)
  (unrealized (0 1))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (3 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 33)
  (parent 15)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 4 1 resp1 2) nb-0 (3 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 34)
  (parent 16)
  (seen 19)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (3 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 35)
  (parent 16)
  (seen 19)
  (unrealized (0 1) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d)) (enc a b d na nb (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a)))))
  (label 36)
  (parent 17)
  (unrealized)
  (shape)
  (maps ((0) ((a a) (b b) (c c) (d d) (na na) (nb nb) (nc nc) (nd nd))))
  (origs (na (0 0))))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 37)
  (parent 17)
  (seen 84)
  (unrealized (0 1) (4 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 38)
  (parent 17)
  (unrealized (0 1) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 39)
  (parent 17)
  (seen 84)
  (unrealized (0 1) (4 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 5 1 resp1 2) na (4 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 40)
  (parent 18)
  (seen 17)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (4 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 41)
  (parent 18)
  (unrealized (0 1) (3 0) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 42)
  (parent 19)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 43)
  (parent 19)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 44)
  (parent 19)
  (unrealized (0 1) (3 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 45)
  (parent 20)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 46)
  (parent 20)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 47)
  (parent 20)
  (seen 46 105)
  (unrealized (0 1) (3 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 48)
  (parent 21)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 49)
  (parent 21)
  (seen 63)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 50)
  (parent 21)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 51)
  (parent 21)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 52)
  (parent 22)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 53)
  (parent 22)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 54)
  (parent 22)
  (seen 52)
  (unrealized (0 1) (4 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 55)
  (parent 23)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 56)
  (parent 23)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 57)
  (parent 23)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 58)
  (parent 23)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 59)
  (parent 24)
  (seen 127)
  (unrealized (0 1) (2 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 60)
  (parent 25)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 61)
  (parent 25)
  (seen 138)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 62)
  (parent 25)
  (seen 140)
  (unrealized (0 1) (2 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 63)
  (parent 26)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 64)
  (parent 26)
  (unrealized (0 1) (4 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 65)
  (parent 26)
  (unrealized (0 1) (4 0) (6 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 66)
  (parent 27)
  (unrealized (0 1) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 67)
  (parent 27)
  (seen 157)
  (unrealized (0 1) (2 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 68)
  (parent 27)
  (unrealized (0 1) (2 0) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 70)
  (parent 28)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 71)
  (parent 28)
  (seen 81)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 72)
  (parent 28)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-1 (4 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 73)
  (parent 28)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 74)
  (parent 29)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 75)
  (parent 30)
  (seen 59)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 76)
  (parent 30)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 77)
  (parent 30)
  (seen 76 184)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 78)
  (parent 31)
  (seen 19)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 79)
  (parent 32)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 80)
  (parent 32)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 4 resp1 2) nb-1 (3 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 81)
  (parent 33)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (3 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 82)
  (parent 33)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 83)
  (parent 33)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 4 2 resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 84)
  (parent 34)
  (seen 193)
  (unrealized (0 1))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 85)
  (parent 34)
  (seen 103)
  (unrealized (0 1) (3 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 86)
  (parent 35)
  (seen 92)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 87)
  (parent 38)
  (seen 213)
  (unrealized (0 1))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 88)
  (parent 40)
  (seen 214)
  (unrealized (0 1) (3 0) (5 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 89)
  (parent 40)
  (unrealized (0 1) (3 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0)) na (4 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-0 (pubk c)))))
  (label 90)
  (parent 41)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (4 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 91)
  (parent 41)
  (unrealized (0 1) (3 0) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 92)
  (parent 42)
  (seen 111)
  (unrealized (0 1) (3 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 93)
  (parent 42)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 94)
  (parent 42)
  (seen 93 111)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-0 (pubk c)))))
  (label 95)
  (parent 43)
  (seen 210)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 96)
  (parent 43)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 97)
  (parent 43)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 98)
  (parent 43)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 99)
  (parent 43)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 100)
  (parent 43)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 101)
  (parent 43)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 102)
  (parent 44)
  (seen 43)
  (unrealized (0 1) (3 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 103)
  (parent 44)
  (unrealized (0 1) (3 0) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 104)
  (parent 45)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 105)
  (parent 45)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 106)
  (parent 45)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0)) na (3 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 107)
  (parent 46)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 108)
  (parent 46)
  (seen 223)
  (unrealized (0 1) (3 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 109)
  (parent 46)
  (unrealized (0 1) (3 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 110)
  (parent 46)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 111)
  (parent 47)
  (seen 230)
  (unrealized (0 1) (3 0) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 113)
  (parent 48)
  (seen 148)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 114)
  (parent 50)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 115)
  (parent 50)
  (seen 294)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 116)
  (parent 50)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 117)
  (parent 51)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 118)
  (parent 51)
  (seen 301)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 119)
  (parent 51)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (4 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 120)
  (parent 52)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 121)
  (parent 52)
  (unrealized (0 1) (4 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (4 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 122)
  (parent 52)
  (unrealized (0 1) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 123)
  (parent 53)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 124)
  (parent 53)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 125)
  (parent 54)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 127)
  (parent 55)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 128)
  (parent 56)
  (seen 331)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 129)
  (parent 57)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 130)
  (parent 57)
  (seen 339)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 131)
  (parent 57)
  (seen 341)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 132)
  (parent 58)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 133)
  (parent 58)
  (seen 346)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 134)
  (parent 58)
  (seen 348)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 135)
  (parent 59)
  (seen 127)
  (unrealized (0 1) (2 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 136)
  (parent 59)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 137)
  (parent 59)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 138)
  (parent 60)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 139)
  (parent 60)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 140)
  (parent 61)
  (unrealized (0 1) (2 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 141)
  (parent 61)
  (unrealized (0 1) (2 0) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 142)
  (parent 62)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 143)
  (parent 62)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 145)
  (parent 63)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 146)
  (parent 63)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 147)
  (parent 63)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 148)
  (parent 63)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 149)
  (parent 63)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 150)
  (parent 63)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 151)
  (parent 64)
  (unrealized (0 1) (4 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 152)
  (parent 64)
  (seen 401)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 153)
  (parent 64)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 155)
  (parent 65)
  (unrealized (0 1) (4 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 156)
  (parent 65)
  (unrealized (0 1) (4 0) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 157)
  (parent 66)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 158)
  (parent 66)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 160)
  (parent 67)
  (unrealized (0 1) (2 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 162)
  (parent 68)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 163)
  (parent 68)
  (unrealized (0 1) (2 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 166)
  (parent 70)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 167)
  (parent 70)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 168)
  (parent 70)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (3 0))
    ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 169)
  (parent 71)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-1 (4 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 170)
  (parent 71)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 171)
  (parent 71)
  (unrealized (0 1) (4 0) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-2 (4 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 172)
  (parent 72)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 5 resp1 2) nb-2 (4 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 173)
  (parent 72)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 174)
  (parent 72)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 175)
  (parent 72)
  (unrealized (0 1) (4 0) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 176)
  (parent 73)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 177)
  (parent 73)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 178)
  (parent 73)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 179)
  (parent 74)
  (seen 440)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 180)
  (parent 74)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 181)
  (parent 74)
  (seen 196)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 182)
  (parent 74)
  (seen 198)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 183)
  (parent 75)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 184)
  (parent 75)
  (seen 135 183)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 185)
  (parent 75)
  (seen 59)
  (unrealized (0 1) (4 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 186)
  (parent 76)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 187)
  (parent 76)
  (seen 444 480)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 188)
  (parent 76)
  (seen 492)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 189)
  (parent 76)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 190)
  (parent 76)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 191)
  (parent 76)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 192)
  (parent 77)
  (unrealized (0 1) (4 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 193)
  (parent 78)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 194)
  (parent 78)
  (seen 103)
  (unrealized (0 1) (4 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 195)
  (parent 79)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 196)
  (parent 79)
  (seen 534)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 197)
  (parent 80)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 198)
  (parent 80)
  (seen 539)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 199)
  (parent 81)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 200)
  (parent 81)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 201)
  (parent 81)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 202)
  (parent 82)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 203)
  (parent 82)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 204)
  (parent 82)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 205)
  (parent 82)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 206)
  (parent 82)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 207)
  (parent 83)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 208)
  (parent 83)
  (unrealized (0 1) (3 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 209)
  (parent 83)
  (seen 208 573)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a)))))
  (label 210)
  (parent 84)
  (seen 36)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 211)
  (parent 84)
  (seen 535)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 212)
  (parent 84)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 213)
  (parent 84)
  (unrealized (0 1) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 214)
  (parent 85)
  (seen 84 102)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 215)
  (parent 86)
  (seen 93)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 216)
  (parent 86)
  (seen 111 215)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nc
    (0 1) (enc a b c nc nb nc (pubk d)) (enc a b d nc nb (pubk c))
    (enc a c d nc (pubk b)) (enc b c d nc nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nc (pubk b)))
      (recv (enc b c d nc nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nb (pubk c))))
    ((recv (enc a b d nc nb (pubk c)))
      (send (enc a b c nc nb nc (pubk d))))
    ((recv (enc a b c nc nb nc (pubk d)))
      (send (enc b c d nc nb nc nd (pubk a)))))
  (label 217)
  (parent 87)
  (seen 36)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c)))))
  (label 218)
  (parent 87)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 219)
  (parent 87)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 220)
  (parent 87)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 221)
  (parent 89)
  (unrealized (0 1) (3 0) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (5 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 222)
  (parent 89)
  (seen 599 600)
  (unrealized (0 1) (3 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nd-0 nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nc-1 nc-0)) na (3 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-0 (pubk c)))))
  (label 223)
  (parent 90)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 224)
  (parent 90)
  (seen 261)
  (unrealized (0 1) (3 0) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-0 (pubk c)))))
  (label 225)
  (parent 90)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 226)
  (parent 90)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 227)
  (parent 91)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 228)
  (parent 91)
  (unrealized (0 1) (3 0) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 230)
  (parent 92)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 231)
  (parent 92)
  (seen 287)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 232)
  (parent 92)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0)) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d)))))
  (label 233)
  (parent 93)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 234)
  (parent 93)
  (seen 609)
  (unrealized (0 1))
  (comment "10 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 235)
  (parent 93)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 236)
  (parent 93)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nc (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c)))))
  (label 238)
  (parent 96)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 239)
  (parent 96)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 240)
  (parent 96)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 241)
  (parent 96)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 242)
  (parent 96)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 243)
  (parent 96)
  (seen 256)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 244)
  (parent 97)
  (seen 654)
  (unrealized (0 1))
  (comment "7 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 245)
  (parent 97)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 246)
  (parent 97)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 247)
  (parent 98)
  (seen 99 658)
  (unrealized (0 1))
  (comment "6 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 248)
  (parent 98)
  (seen 676)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 249)
  (parent 98)
  (seen 679)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 250)
  (parent 99)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 251)
  (parent 99)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 252)
  (parent 99)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 253)
  (parent 100)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 254)
  (parent 100)
  (seen 663)
  (unrealized (0 1))
  (comment "10 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 255)
  (parent 100)
  (seen 707)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c)))))
  (label 256)
  (parent 101)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 257)
  (parent 102)
  (unrealized (0 1) (3 0) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 258)
  (parent 102)
  (unrealized (0 1) (3 0) (6 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 259)
  (parent 102)
  (seen 647)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 260)
  (parent 102)
  (unrealized (0 1) (3 0) (6 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 5 resp1 2) nb-1 (4 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 261)
  (parent 103)
  (seen 233)
  (unrealized (0 1) (3 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 262)
  (parent 103)
  (unrealized (0 1) (3 0))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 263)
  (parent 103)
  (unrealized (0 1) (3 0) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 264)
  (parent 104)
  (unrealized (0 1) (3 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 265)
  (parent 104)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 266)
  (parent 104)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 267)
  (parent 104)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp1 2) na (5 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 268)
  (parent 105)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 269)
  (parent 105)
  (seen 231)
  (unrealized (0 1) (5 0) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 270)
  (parent 105)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 271)
  (parent 106)
  (unrealized (0 1) (3 0) (5 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 272)
  (parent 106)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nd nb nc text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d)) (enc a b d na nb (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d)))))
  (label 274)
  (parent 107)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 275)
  (parent 107)
  (seen 586)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 276)
  (parent 107)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 277)
  (parent 107)
  (seen 586)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 278)
  (parent 108)
  (unrealized (0 1) (3 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d)))))
  (label 279)
  (parent 108)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 280)
  (parent 108)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 281)
  (parent 108)
  (seen 283)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 282)
  (parent 109)
  (seen 586 783)
  (unrealized (0 1) (3 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 283)
  (parent 110)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 284)
  (parent 110)
  (seen 798)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 287)
  (parent 111)
  (seen 627)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c)))))
  (label 289)
  (parent 113)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 290)
  (parent 113)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 291)
  (parent 113)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 292)
  (parent 113)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 293)
  (parent 113)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 294)
  (parent 114)
  (seen 299)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 295)
  (parent 114)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 296)
  (parent 115)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 297)
  (parent 116)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 298)
  (parent 116)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 299)
  (parent 116)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 301)
  (parent 117)
  (seen 306)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 302)
  (parent 117)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 303)
  (parent 118)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 304)
  (parent 119)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 305)
  (parent 119)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 306)
  (parent 119)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 308)
  (parent 120)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 309)
  (parent 120)
  (seen 410)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 310)
  (parent 120)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 311)
  (parent 120)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 312)
  (parent 120)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 313)
  (parent 121)
  (seen 155 410)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 314)
  (parent 122)
  (unrealized (0 1) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 315)
  (parent 122)
  (seen 876)
  (unrealized (0 1) (6 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 317)
  (parent 123)
  (seen 325)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 318)
  (parent 123)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 319)
  (parent 123)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 320)
  (parent 123)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 321)
  (parent 123)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 322)
  (parent 124)
  (unrealized (0 1) (6 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 323)
  (parent 124)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d)))))
  (label 325)
  (parent 125)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c)))))
  (label 328)
  (parent 127)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 329)
  (parent 127)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 330)
  (parent 127)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 331)
  (parent 127)
  (seen 394)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 332)
  (parent 127)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 333)
  (parent 127)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 334)
  (parent 128)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 335)
  (parent 128)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 336)
  (parent 128)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 337)
  (parent 128)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 338)
  (parent 128)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 339)
  (parent 129)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 340)
  (parent 129)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 341)
  (parent 130)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 342)
  (parent 130)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 343)
  (parent 131)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 344)
  (parent 131)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 3 resp1 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 346)
  (parent 132)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 347)
  (parent 132)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 348)
  (parent 133)
  (seen 961)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 349)
  (parent 133)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 350)
  (parent 134)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 351)
  (parent 134)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d)))))
  (label 353)
  (parent 135)
  (unrealized (0 1) (2 0) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 354)
  (parent 135)
  (seen 359)
  (unrealized (0 1) (2 0) (6 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 355)
  (parent 135)
  (unrealized (0 1) (2 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 356)
  (parent 135)
  (seen 362)
  (unrealized (0 1) (2 0) (6 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 357)
  (parent 136)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 358)
  (parent 136)
  (seen 983)
  (unrealized (0 1) (2 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 359)
  (parent 136)
  (unrealized (0 1) (2 0) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 360)
  (parent 137)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 361)
  (parent 137)
  (seen 143 999)
  (unrealized (0 1) (2 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 362)
  (parent 137)
  (seen 143)
  (unrealized (0 1) (2 0) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 363)
  (parent 138)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 364)
  (parent 138)
  (seen 373)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 365)
  (parent 138)
  (seen 367)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 366)
  (parent 139)
  (seen 1013)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 367)
  (parent 139)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 1 resp1 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 369)
  (parent 140)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)) (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 370)
  (parent 140)
  (seen 1001)
  (unrealized (0 1) (2 0) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (2 0)
    (enc a b c nc-1 nb-1 nc-1 (pubk d)) (enc a b d nc-1 nb-1 (pubk c))
    (enc a c d nc-1 (pubk b)) (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 371)
  (parent 140)
  (unrealized (0 1) (2 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)) (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 372)
  (parent 140)
  (seen 1001)
  (unrealized (0 1) (2 0) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 373)
  (parent 141)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 374)
  (parent 141)
  (seen 140 1011)
  (unrealized (0 1) (2 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 376)
  (parent 142)
  (unrealized (0 1))
  (comment "8 in cohort - 8 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 380)
  (parent 143)
  (unrealized (0 1) (2 0))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 382)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 383)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 384)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 385)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 386)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 387)
  (parent 145)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 388)
  (parent 146)
  (seen 1048)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 389)
  (parent 146)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 390)
  (parent 146)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 391)
  (parent 147)
  (seen 1052 1070)
  (unrealized (0 1))
  (comment "6 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 392)
  (parent 147)
  (seen 1074)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 393)
  (parent 147)
  (seen 1077)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 394)
  (parent 148)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 395)
  (parent 149)
  (seen 297)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 396)
  (parent 149)
  (seen 1094)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 397)
  (parent 149)
  (seen 297)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 398)
  (parent 150)
  (seen 304)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 399)
  (parent 150)
  (seen 1099)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 400)
  (parent 150)
  (seen 304)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 401)
  (parent 151)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 402)
  (parent 151)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 405)
  (parent 152)
  (unrealized (0 1))
  (comment "9 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 407)
  (parent 153)
  (unrealized (0 1))
  (comment "9 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 410)
  (parent 155)
  (unrealized (0 1))
  (comment "8 in cohort - 8 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 415)
  (parent 156)
  (unrealized (0 1))
  (comment "13 in cohort - 13 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 416)
  (parent 156)
  (seen 155 410 874 875)
  (unrealized (0 1) (4 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 417)
  (parent 156)
  (unrealized (0 1) (4 0))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 419)
  (parent 157)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 422)
  (parent 158)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 426)
  (parent 160)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 431)
  (parent 162)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 435)
  (parent 163)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 440)
  (parent 166)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 441)
  (parent 166)
  (seen 559)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 442)
  (parent 166)
  (seen 202)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 443)
  (parent 167)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 444)
  (parent 167)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 445)
  (parent 167)
  (seen 444 1196)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 446)
  (parent 168)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 447)
  (parent 168)
  (seen 1204)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 448)
  (parent 168)
  (seen 1205)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 449)
  (parent 169)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 450)
  (parent 169)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 451)
  (parent 169)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 452)
  (parent 170)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 453)
  (parent 170)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 454)
  (parent 170)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 455)
  (parent 171)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 456)
  (parent 171)
  (seen 577)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 457)
  (parent 171)
  (seen 456 1230)
  (unrealized (0 1) (4 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 458)
  (parent 171)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 459)
  (parent 172)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 460)
  (parent 172)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 461)
  (parent 172)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 462)
  (parent 172)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 463)
  (parent 172)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c)))))
  (label 464)
  (parent 173)
  (seen 1264 1265)
  (unrealized (0 1))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 465)
  (parent 173)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 466)
  (parent 173)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a)))))
  (label 467)
  (parent 173)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))))
  (label 468)
  (parent 173)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (5 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 469)
  (parent 174)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (5 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 470)
  (parent 174)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (5 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 471)
  (parent 174)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (5 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 472)
  (parent 174)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (5 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 473)
  (parent 174)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 474)
  (parent 175)
  (seen 145)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 475)
  (parent 175)
  (seen 574 1302)
  (unrealized (0 1) (4 0) (6 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 476)
  (parent 175)
  (seen 334)
  (unrealized (0 1) (4 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-2 (6 0)
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 478)
  (parent 175)
  (seen 1306)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 479)
  (parent 176)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 480)
  (parent 176)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 481)
  (parent 176)
  (seen 480 1317)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 482)
  (parent 177)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 483)
  (parent 177)
  (seen 1325)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 484)
  (parent 177)
  (seen 1326)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 485)
  (parent 178)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 486)
  (parent 178)
  (seen 1332)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 487)
  (parent 178)
  (seen 1330 1333)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 488)
  (parent 179)
  (seen 1211)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 489)
  (parent 179)
  (seen 1266 1286)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 490)
  (parent 179)
  (seen 176 177 178)
  (unrealized (0 1))
  (comment "3 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 491)
  (parent 180)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 492)
  (parent 180)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 493)
  (parent 180)
  (seen 492 1344)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 494)
  (parent 181)
  (seen 534)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 495)
  (parent 182)
  (seen 539)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 496)
  (parent 183)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 497)
  (parent 183)
  (seen 1195 1316)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 498)
  (parent 183)
  (seen 1343)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 499)
  (parent 183)
  (seen 8)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 500)
  (parent 183)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 501)
  (parent 183)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 502)
  (parent 184)
  (seen 523)
  (unrealized (0 1) (4 0) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 503)
  (parent 184)
  (seen 135 505)
  (unrealized (0 1) (4 0) (6 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 504)
  (parent 185)
  (seen 113)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 505)
  (parent 185)
  (unrealized (0 1) (4 0) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 506)
  (parent 186)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 507)
  (parent 186)
  (seen 1348)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 508)
  (parent 186)
  (seen 173)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 509)
  (parent 186)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 510)
  (parent 186)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 511)
  (parent 186)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 512)
  (parent 187)
  (seen 456 1215 1221)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 513)
  (parent 187)
  (seen 456 1271 1295)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 514)
  (parent 188)
  (seen 208 564 1406)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 515)
  (parent 188)
  (seen 208 1408)
  (unrealized (0 1) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 516)
  (parent 189)
  (seen 1416)
  (unrealized (0 1))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 517)
  (parent 190)
  (seen 282)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 518)
  (parent 190)
  (seen 1417)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 519)
  (parent 190)
  (seen 1418 1420)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 520)
  (parent 191)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 521)
  (parent 191)
  (seen 215 1424)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 522)
  (parent 191)
  (seen 215 1425)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 523)
  (parent 192)
  (unrealized (0 1) (4 0) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 524)
  (parent 192)
  (seen 1431)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 525)
  (parent 192)
  (seen 1378)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nb-0 nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a)))))
  (label 527)
  (parent 193)
  (seen 210)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 528)
  (parent 193)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 529)
  (parent 193)
  (seen 580 1355)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 530)
  (parent 193)
  (seen 582)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 531)
  (parent 193)
  (seen 1426)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 532)
  (parent 193)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 533)
  (parent 194)
  (seen 102 193)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 534)
  (parent 195)
  (seen 247)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 535)
  (parent 195)
  (seen 212 1355)
  (unrealized (0 1))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 536)
  (parent 195)
  (seen 1451)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 537)
  (parent 195)
  (unrealized (0 1) (4 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 538)
  (parent 196)
  (unrealized (0 1) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 539)
  (parent 197)
  (unrealized (0 1) (4 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 540)
  (parent 197)
  (seen 1464)
  (unrealized (0 1) (4 0))
  (comment "5 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 541)
  (parent 197)
  (seen 1359)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 542)
  (parent 197)
  (seen 540)
  (unrealized (0 1) (4 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 543)
  (parent 198)
  (unrealized (0 1) (4 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 544)
  (parent 199)
  (seen 1193 1268)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 545)
  (parent 199)
  (seen 1411)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 546)
  (parent 199)
  (seen 550)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 547)
  (parent 199)
  (seen 553)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 548)
  (parent 200)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 549)
  (parent 200)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 550)
  (parent 200)
  (seen 1490 1494)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 551)
  (parent 201)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 552)
  (parent 201)
  (seen 676)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 553)
  (parent 201)
  (seen 1499 1503)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 554)
  (parent 202)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 555)
  (parent 202)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 556)
  (parent 202)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 557)
  (parent 202)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 558)
  (parent 202)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 559)
  (parent 203)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 560)
  (parent 203)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 561)
  (parent 203)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 562)
  (parent 203)
  (unrealized (0 1))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 563)
  (parent 204)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 564)
  (parent 204)
  (seen 1512)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 565)
  (parent 204)
  (seen 1542)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 566)
  (parent 205)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 567)
  (parent 205)
  (seen 1552)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 568)
  (parent 205)
  (seen 1553)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 569)
  (parent 206)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 570)
  (parent 206)
  (seen 1559)
  (unrealized (0 1) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 571)
  (parent 206)
  (seen 1560)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 572)
  (parent 207)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 573)
  (parent 207)
  (seen 572)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 574)
  (parent 207)
  (seen 1573)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 575)
  (parent 207)
  (seen 574)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 576)
  (parent 208)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 5 resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 577)
  (parent 208)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 578)
  (parent 208)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 580)
  (parent 211)
  (seen 1500 1554)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 581)
  (parent 212)
  (seen 1444)
  (unrealized (0 1))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 582)
  (parent 212)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 583)
  (parent 213)
  (seen 1447)
  (unrealized (0 1))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 584)
  (parent 214)
  (seen 733)
  (unrealized (0 1) (3 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 585)
  (parent 214)
  (seen 737)
  (unrealized (0 1) (3 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0)) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d)))))
  (label 586)
  (parent 215)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 587)
  (parent 215)
  (unrealized (0 1) (3 0) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 588)
  (parent 215)
  (seen 650)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nc
    (0 1) (enc a b c nc nb nc (pubk d)) (enc a b d nc nb (pubk c))
    (enc a b d nc nd (pubk c)) (enc a c d nc (pubk b))
    (enc b c d nc nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nc (pubk b)))
      (recv (enc b c d nc nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nb (pubk c))))
    ((recv (enc a b d nc nb (pubk c)))
      (send (enc a b c nc nb nc (pubk d))))
    ((recv (enc a b c nc nb nc (pubk d)))
      (send (enc b c d nc nb nc nd (pubk a))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nd (pubk c)))))
  (label 590)
  (parent 218)
  (seen 217)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nd-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nd-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nd-0 (pubk c)))
      (send (enc a b c nc-0 nd-0 nc-1 (pubk d)))))
  (label 591)
  (parent 218)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nd-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 592)
  (parent 218)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nd-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 593)
  (parent 218)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 594)
  (parent 218)
  (unrealized (0 1) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 1 resp1 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 595)
  (parent 219)
  (seen 1616)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 596)
  (parent 219)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 1 resp1 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 597)
  (parent 220)
  (unrealized (0 1) (4 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (4 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 598)
  (parent 220)
  (seen 1631)
  (unrealized (0 1) (4 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 599)
  (parent 221)
  (unrealized (0 1) (5 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 600)
  (parent 221)
  (unrealized (0 1) (3 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 601)
  (parent 221)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 602)
  (parent 222)
  (unrealized (0 1) (3 0) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (na nd nc nb text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d)) (enc a b d na nb (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c)))))
  (label 604)
  (parent 223)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 605)
  (parent 223)
  (seen 233)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 606)
  (parent 223)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 607)
  (parent 223)
  (seen 233)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nc nd nc-0 nb text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-0 nb) (nc-1 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d)) (enc a b c na nb nc-0 (pubk d))
    (enc a b d na nb (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c)))))
  (label 608)
  (parent 225)
  (seen 1648)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 609)
  (parent 225)
  (seen 740)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 610)
  (parent 225)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 611)
  (parent 225)
  (seen 740)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 612)
  (parent 225)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 613)
  (parent 226)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 614)
  (parent 226)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 616)
  (parent 227)
  (unrealized (0 1) (3 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 617)
  (parent 227)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0)) na (4 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 619)
  (parent 228)
  (unrealized (0 1) (3 0))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (4 0)
    (enc a b c na nb-1 nc-2 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 620)
  (parent 228)
  (unrealized (0 1) (3 0))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0)) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d)))))
  (label 623)
  (parent 230)
  (seen 193 210 211 212)
  (unrealized (0 1))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 624)
  (parent 230)
  (unrealized (0 1))
  (comment "10 in cohort - 10 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 625)
  (parent 230)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 626)
  (parent 230)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 627)
  (parent 231)
  (unrealized (0 1))
  (comment "10 in cohort - 10 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 628)
  (parent 231)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 629)
  (parent 231)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 630)
  (parent 232)
  (unrealized (0 1) (3 0) (5 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 631)
  (parent 232)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nd nb nc text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d)))))
  (label 633)
  (parent 233)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 634)
  (parent 233)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 635)
  (parent 233)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 636)
  (parent 233)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 637)
  (parent 233)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 638)
  (parent 234)
  (seen 95)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 639)
  (parent 234)
  (seen 644)
  (unrealized (0 1))
  (comment "8 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 640)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 641)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 642)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 643)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 644)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 645)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 646)
  (parent 234)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 647)
  (parent 235)
  (seen 234)
  (unrealized (0 1) (3 0))
  (comment "8 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 648)
  (parent 235)
  (seen 749)
  (unrealized (0 1) (3 0) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 650)
  (parent 236)
  (unrealized (0 1) (3 0) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 651)
  (parent 236)
  (seen 1771)
  (unrealized (0 1) (3 0) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation generalization deleted (4 0))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c)))))
  (label 653)
  (parent 238)
  (seen 210)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 654)
  (parent 239)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 655)
  (parent 239)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 656)
  (parent 239)
  (seen 1785)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 658)
  (parent 240)
  (unrealized (0 1))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 659)
  (parent 240)
  (seen 1783)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 660)
  (parent 240)
  (seen 1796)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 662)
  (parent 241)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 663)
  (parent 241)
  (seen 716)
  (unrealized (0 1))
  (comment "8 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 664)
  (parent 241)
  (seen 1802)
  (unrealized (0 1) (6 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 666)
  (parent 242)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 667)
  (parent 242)
  (seen 1816)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 668)
  (parent 242)
  (unrealized (0 1))
  (comment "9 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb-0 (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb-0 (pubk d)))))
  (label 670)
  (parent 244)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 671)
  (parent 244)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 672)
  (parent 244)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 673)
  (parent 244)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 674)
  (parent 244)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 675)
  (parent 244)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 676)
  (parent 245)
  (seen 636)
  (unrealized (0 1))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 677)
  (parent 245)
  (seen 1784)
  (unrealized (0 1))
  (comment "7 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 678)
  (parent 245)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 679)
  (parent 246)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 680)
  (parent 246)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 681)
  (parent 246)
  (unrealized (0 1))
  (comment "9 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d)))))
  (label 683)
  (parent 247)
  (seen 1453)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 684)
  (parent 247)
  (seen 1833)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 685)
  (parent 247)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 686)
  (parent 247)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 687)
  (parent 248)
  (seen 1795)
  (unrealized (0 1))
  (comment "6 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 688)
  (parent 248)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 689)
  (parent 249)
  (unrealized (0 1))
  (comment "6 in cohort - 6 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 690)
  (parent 249)
  (unrealized (0 1))
  (comment "8 in cohort - 8 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nd (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d)))))
  (label 692)
  (parent 250)
  (seen 1594)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c)))))
  (label 693)
  (parent 250)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 694)
  (parent 250)
  (seen 1836)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 695)
  (parent 250)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 696)
  (parent 250)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 697)
  (parent 250)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 698)
  (parent 250)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 699)
  (parent 251)
  (unrealized (0 1))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 700)
  (parent 251)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 701)
  (parent 251)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 702)
  (parent 252)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 703)
  (parent 252)
  (unrealized (0 1))
  (comment "7 in cohort - 7 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 704)
  (parent 252)
  (unrealized (0 1))
  (comment "10 in cohort - 10 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 706)
  (parent 253)
  (seen 1801)
  (unrealized (0 1))
  (comment "10 in cohort - 9 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 707)
  (parent 253)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 4 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 708)
  (parent 253)
  (seen 1980)
  (unrealized (0 1) (5 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 709)
  (parent 253)
  (unrealized (0 1) (5 0) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 710)
  (parent 254)
  (seen 95)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 711)
  (parent 254)
  (seen 1840)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 712)
  (parent 254)
  (seen 1883)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 713)
  (parent 254)
  (unrealized (0 1) (6 0))
  (comment "5 in cohort - 5 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 714)
  (parent 254)
  (seen 1920)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 715)
  (parent 254)
  (unrealized (0 1) (6 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 716)
  (parent 254)
  (unrealized (0 1) (6 0))
  (comment "3 in cohort - 3 not yet seen"))

(comment "Step limit exceeded--aborting run")

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 717)
  (parent 254)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 718)
  (parent 254)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-2 nb-1)) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 719)
  (parent 255)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 720)
  (parent 255)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd nb text) (a b c d name))
  (defstrand init 3 (na nc) (nb nc) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc) (nb nc) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc) (nb nc) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc)
  (operation nonce-test (contracted (nb-0 nc) (nc-0 nc) (nd-0 nd)) nc
    (0 1) (enc a b c nc nc nc (pubk d)) (enc a b d nc nc (pubk c))
    (enc a b d nc nb (pubk c)) (enc a c d nc (pubk b))
    (enc b c d nc nc nc nd (pubk a)))
  (traces
    ((send (enc a c d nc (pubk b)))
      (recv (enc b c d nc nc nc nd (pubk a)))
      (send (enc nc nc nd (pubk b))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nc (pubk c))))
    ((recv (enc a b d nc nc (pubk c)))
      (send (enc a b c nc nc nc (pubk d))))
    ((recv (enc a b c nc nc nc (pubk d)))
      (send (enc b c d nc nc nc nd (pubk a))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nb (pubk c)))))
  (label 721)
  (parent 256)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c)))))
  (label 722)
  (parent 256)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 723)
  (parent 256)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d)))))
  (label 724)
  (parent 256)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nb-0 (pubk a)))))
  (label 725)
  (parent 256)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nc-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nc-0 (pubk a)))))
  (label 726)
  (parent 256)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 727)
  (parent 257)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 728)
  (parent 257)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 729)
  (parent 257)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 730)
  (parent 257)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nc-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (displaced 7 5 resp2 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-0 (pubk d))))
    ((recv (enc a b c nc-1 nc-1 nc-0 (pubk d)))
      (send (enc b c d nc-1 nc-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-1 (pubk d))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nb-0 (pubk d)))))
  (label 731)
  (parent 257)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 732)
  (parent 258)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 733)
  (parent 258)
  (unrealized (0 1) (3 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 734)
  (parent 259)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 735)
  (parent 259)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 736)
  (parent 260)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 737)
  (parent 260)
  (unrealized (0 1) (3 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 738)
  (parent 261)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 739)
  (parent 261)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 740)
  (parent 261)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 741)
  (parent 261)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-1 (pubk c)))))
  (label 742)
  (parent 262)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 743)
  (parent 262)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 744)
  (parent 262)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 745)
  (parent 262)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 746)
  (parent 262)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 747)
  (parent 262)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 748)
  (parent 263)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 749)
  (parent 263)
  (unrealized (0 1) (3 0) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 750)
  (parent 263)
  (unrealized (0 1) (3 0) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 751)
  (parent 264)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 752)
  (parent 265)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 753)
  (parent 265)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 754)
  (parent 265)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-1 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 755)
  (parent 265)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 756)
  (parent 265)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 757)
  (parent 265)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 758)
  (parent 266)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 759)
  (parent 266)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 760)
  (parent 266)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 761)
  (parent 267)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 762)
  (parent 267)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 763)
  (parent 267)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 764)
  (parent 268)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 765)
  (parent 268)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 766)
  (parent 268)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-1 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 767)
  (parent 268)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 768)
  (parent 268)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 769)
  (parent 268)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 770)
  (parent 270)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 771)
  (parent 270)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 772)
  (parent 270)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (5 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 773)
  (parent 271)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) na (5 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-2 (pubk d)))))
  (label 774)
  (parent 271)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 775)
  (parent 271)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 776)
  (parent 271)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-1 (pubk a)))))
  (label 777)
  (parent 271)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0)) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 778)
  (parent 272)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 779)
  (parent 272)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 780)
  (parent 272)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nd nb nc text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation generalization deleted (2 0))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d)))))
  (label 781)
  (parent 274)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d)))))
  (label 782)
  (parent 276)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 783)
  (parent 278)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) na
    (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb nc nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d)))))
  (label 784)
  (parent 279)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 785)
  (parent 279)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 786)
  (parent 279)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-1 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 787)
  (parent 279)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 788)
  (parent 279)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 789)
  (parent 279)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 790)
  (parent 280)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 791)
  (parent 280)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 792)
  (parent 280)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 793)
  (parent 281)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 794)
  (parent 281)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 795)
  (parent 282)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 796)
  (parent 282)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (3 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 797)
  (parent 282)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 798)
  (parent 283)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 799)
  (parent 283)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 800)
  (parent 283)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (6 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 801)
  (parent 284)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 802)
  (parent 284)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 803)
  (parent 287)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 804)
  (parent 287)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 805)
  (parent 287)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 806)
  (parent 287)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 807)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 808)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 809)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nc-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nc-1 (pubk c)))
      (send (enc a b c nb-1 nc-1 nc-2 (pubk d)))))
  (label 810)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 811)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 812)
  (parent 289)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 813)
  (parent 290)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 814)
  (parent 290)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 815)
  (parent 290)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 816)
  (parent 291)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 817)
  (parent 291)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 818)
  (parent 291)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 819)
  (parent 292)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 820)
  (parent 292)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 821)
  (parent 292)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 822)
  (parent 293)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 823)
  (parent 293)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 824)
  (parent 293)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 825)
  (parent 294)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 826)
  (parent 294)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 827)
  (parent 295)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 828)
  (parent 295)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 829)
  (parent 295)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 830)
  (parent 296)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 831)
  (parent 296)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 832)
  (parent 296)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 833)
  (parent 297)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 834)
  (parent 297)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 835)
  (parent 297)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 836)
  (parent 298)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 837)
  (parent 298)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 838)
  (parent 298)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nb-0 nc-0 nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0) (nd-0 nd))
    na (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb-0 nc-0 nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb-0 nc-0 nd (pubk a)))
      (send (enc nb-0 nc-0 nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd (pubk a)))))
  (label 839)
  (parent 299)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 840)
  (parent 299)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 841)
  (parent 299)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nb-0 nc-0 (pubk d))
    (enc a b c nc-1 nb-1 nc-1 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 842)
  (parent 299)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 843)
  (parent 299)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 844)
  (parent 299)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 845)
  (parent 301)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 846)
  (parent 301)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 847)
  (parent 302)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 848)
  (parent 302)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 849)
  (parent 302)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 850)
  (parent 303)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 851)
  (parent 303)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 852)
  (parent 303)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 853)
  (parent 304)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 854)
  (parent 304)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 855)
  (parent 304)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 856)
  (parent 305)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 857)
  (parent 305)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 858)
  (parent 305)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (2 0))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0)) na (5 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 859)
  (parent 306)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 860)
  (parent 306)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (5 0))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (5 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 861)
  (parent 306)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 862)
  (parent 306)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 863)
  (parent 306)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d)))))
  (label 864)
  (parent 308)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 865)
  (parent 310)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 866)
  (parent 310)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 867)
  (parent 310)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 868)
  (parent 311)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 869)
  (parent 311)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 870)
  (parent 311)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 871)
  (parent 312)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 872)
  (parent 312)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 873)
  (parent 312)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 874)
  (parent 313)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-0 (pubk a)))))
  (label 875)
  (parent 313)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 876)
  (parent 314)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (6 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 877)
  (parent 314)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 878)
  (parent 314)
  (unrealized (0 1) (4 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 879)
  (parent 315)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 880)
  (parent 318)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 881)
  (parent 319)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 882)
  (parent 319)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 883)
  (parent 319)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 884)
  (parent 320)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a)))))
  (label 885)
  (parent 320)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 886)
  (parent 320)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 887)
  (parent 321)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 888)
  (parent 321)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 889)
  (parent 321)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 890)
  (parent 322)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 nc-4 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-4) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-4 (pubk d)))))
  (label 891)
  (parent 322)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (5 0)
    (enc a b c na nb-1 nc-3 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 892)
  (parent 323)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 nc-4 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-4) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b c nb-1 nb-1 nc-3 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-4 (pubk d)))))
  (label 893)
  (parent 323)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-3) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-1 nc-3 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d))))
    ((recv (enc a b c na nb-1 nc-3 (pubk d)))
      (send (enc b c d na nb-1 nc-3 nd-0 (pubk a)))))
  (label 894)
  (parent 323)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c)))))
  (label 895)
  (parent 325)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 896)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 897)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 898)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 899)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-2 nd-0 (pubk a)))))
  (label 900)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-0 nc-2 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 901)
  (parent 325)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 902)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 903)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 904)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nc-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b d nb-1 nc-1 (pubk c)))
      (send (enc a b c nb-1 nc-1 nc-2 (pubk d)))))
  (label 905)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 906)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nc-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 907)
  (parent 328)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 908)
  (parent 329)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 909)
  (parent 329)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 910)
  (parent 329)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 911)
  (parent 330)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 912)
  (parent 330)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 913)
  (parent 330)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 914)
  (parent 331)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (displaced 6 4 resp2 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-1 (pubk d))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-2 (pubk d)))))
  (label 915)
  (parent 331)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 916)
  (parent 332)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 917)
  (parent 332)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 918)
  (parent 332)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 919)
  (parent 333)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a)))))
  (label 920)
  (parent 333)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (5 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 921)
  (parent 333)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 922)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 923)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 924)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 925)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 926)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 927)
  (parent 334)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 928)
  (parent 335)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 929)
  (parent 335)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 930)
  (parent 335)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 931)
  (parent 336)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 932)
  (parent 336)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 933)
  (parent 336)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 934)
  (parent 337)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 935)
  (parent 337)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 936)
  (parent 337)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 937)
  (parent 338)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 938)
  (parent 338)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 939)
  (parent 338)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 940)
  (parent 339)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 941)
  (parent 339)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 942)
  (parent 339)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 943)
  (parent 340)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 944)
  (parent 340)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 945)
  (parent 340)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nb-0 nc-0 nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0) (nd-0 nd))
    na (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb-0 nc-0 nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb-0 nc-0 nd (pubk a)))
      (send (enc nb-0 nc-0 nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd (pubk a)))))
  (label 946)
  (parent 341)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 947)
  (parent 341)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 948)
  (parent 341)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nb-0 nc-0 (pubk d))
    (enc a b c nc-1 nb-1 nc-1 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 949)
  (parent 341)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 950)
  (parent 341)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 951)
  (parent 341)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 952)
  (parent 342)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 953)
  (parent 342)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 954)
  (parent 342)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 955)
  (parent 343)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 956)
  (parent 343)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 957)
  (parent 343)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 958)
  (parent 344)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 959)
  (parent 344)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 960)
  (parent 344)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 961)
  (parent 346)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 962)
  (parent 346)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 963)
  (parent 346)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 964)
  (parent 347)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 965)
  (parent 347)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 966)
  (parent 347)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 967)
  (parent 348)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a)))))
  (label 968)
  (parent 348)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 969)
  (parent 349)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 970)
  (parent 349)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 971)
  (parent 349)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 972)
  (parent 350)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 973)
  (parent 350)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 974)
  (parent 350)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 975)
  (parent 351)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 976)
  (parent 351)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 977)
  (parent 351)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d)))))
  (label 978)
  (parent 353)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (4 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d)))))
  (label 979)
  (parent 353)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d)))))
  (label 980)
  (parent 353)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-3 (pubk c)))))
  (label 981)
  (parent 353)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (6 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (displaced 7 4 resp2 2) nb-2 (6 0)
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-1 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nb-1 (pubk d)))))
  (label 982)
  (parent 353)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 983)
  (parent 354)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 984)
  (parent 355)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 985)
  (parent 355)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 986)
  (parent 355)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-3 (pubk c)))))
  (label 987)
  (parent 355)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 988)
  (parent 356)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 989)
  (parent 357)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 990)
  (parent 357)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d)))))
  (label 991)
  (parent 357)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 1 resp1 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nb-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 992)
  (parent 358)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nb-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 993)
  (parent 358)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nb-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))))
  (label 994)
  (parent 358)
  (unrealized (0 1) (2 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 995)
  (parent 359)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 996)
  (parent 359)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 997)
  (parent 359)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 998)
  (parent 359)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 999)
  (parent 360)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d)))))
  (label 1000)
  (parent 360)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 4 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1001)
  (parent 361)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 1002)
  (parent 361)
  (unrealized (0 1) (2 0) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1003)
  (parent 362)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 1004)
  (parent 362)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nb-0 nc-0 nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0) (nd-0 nd))
    na (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb-0 nc-0 nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb-0 nc-0 nd (pubk a)))
      (send (enc nb-0 nc-0 nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd (pubk a)))))
  (label 1005)
  (parent 363)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 1006)
  (parent 363)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1007)
  (parent 363)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nb-0 nc-0 (pubk d))
    (enc a b c nc-1 nb-1 nc-1 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1008)
  (parent 363)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1009)
  (parent 363)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 1010)
  (parent 363)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 1011)
  (parent 364)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 1012)
  (parent 364)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1013)
  (parent 365)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 1014)
  (parent 365)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-2 nc-1)) na (5 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 1015)
  (parent 366)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1016)
  (parent 366)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-0 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-1 (pubk a)))))
  (label 1017)
  (parent 366)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1018)
  (parent 367)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (6 0)) ((5 1) (2 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1019)
  (parent 367)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 1020)
  (parent 367)
  (unrealized (0 1) (5 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nb-0 nc-0 nd text) (a b c d name))
  (defstrand init 3 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0) (nd-0 nd))
    na (0 1) (enc a b c na nb nc (pubk d))
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb (pubk c))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b))
    (enc b c d na nb-0 nc-0 nd (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb-0 nc-0 nd (pubk a)))
      (send (enc nb-0 nc-0 nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd (pubk a)))))
  (label 1021)
  (parent 369)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 1022)
  (parent 369)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1023)
  (parent 369)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nb-0 nc-0 (pubk d))
    (enc a b c nc-1 nb-1 nc-1 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1024)
  (parent 369)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1025)
  (parent 369)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 1026)
  (parent 369)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (0 1)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (displaced 7 4 resp2 2) nc-1 (6 0)
    (enc a c d nc-1 (pubk b)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b d nc-1 nb-1 (pubk c)))
      (send (enc a b c nc-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1027)
  (parent 371)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0)) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1028)
  (parent 373)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (6 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 3 resp1 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 1029)
  (parent 373)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 1030)
  (parent 373)
  (unrealized (0 1) (5 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1031)
  (parent 374)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-1 nc-2 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-2 (pubk d)))
      (send (enc b c d na nb-1 nc-2 nd-1 (pubk a)))))
  (label 1032)
  (parent 374)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nb-0 nc-0 nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb) (nb nb-0) (nc nc-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (5 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-1 nc-0) (nd-0 nd))
    nb (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb-0 nc-0 nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb-0 nc-0 nd (pubk a)))
      (send (enc nb-0 nc-0 nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb nb-0 nc-0 (pubk d)))
      (send (enc b c d nb nb-0 nc-0 nd (pubk a)))))
  (label 1033)
  (parent 376)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1034)
  (parent 376)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1035)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1036)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1037)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nb-0 nc-1 (pubk d))
    (enc a b c nc-1 nc-1 nc-0 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a b d nc-1 nc-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nb-0 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nc-1 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-0 nc-1 nd-1 (pubk a)))))
  (label 1038)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 1039)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1040)
  (parent 376)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-1 (pubk c)))))
  (label 1041)
  (parent 380)
  (unrealized (0 1) (2 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (2 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 1042)
  (parent 380)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-2 (pubk d)))))
  (label 1043)
  (parent 380)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1044)
  (parent 380)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d)))))
  (label 1045)
  (parent 380)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 1046)
  (parent 380)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nc-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nc-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (5 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (2 0)
    (enc a b c nc-1 nc-1 nc-1 (pubk d)) (enc a b d nc-1 nc-1 (pubk c))
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b))
    (enc b c d nc-1 nc-1 nc-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nc-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nc-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-1 (pubk c))))
    ((recv (enc a b c nc-1 nc-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nc-1 nc-1 nd-1 (pubk a)))))
  (label 1047)
  (parent 380)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1048)
  (parent 382)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1049)
  (parent 382)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1050)
  (parent 382)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1051)
  (parent 382)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1052)
  (parent 383)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1053)
  (parent 383)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1054)
  (parent 383)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1055)
  (parent 383)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1056)
  (parent 384)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1057)
  (parent 385)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1058)
  (parent 385)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1059)
  (parent 385)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1060)
  (parent 385)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1061)
  (parent 386)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1062)
  (parent 386)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1063)
  (parent 386)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1064)
  (parent 386)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1065)
  (parent 387)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1066)
  (parent 387)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1067)
  (parent 387)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1068)
  (parent 387)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1069)
  (parent 388)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1070)
  (parent 388)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1071)
  (parent 388)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1072)
  (parent 388)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1073)
  (parent 388)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1074)
  (parent 389)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1075)
  (parent 389)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1076)
  (parent 389)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1077)
  (parent 390)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1078)
  (parent 390)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1079)
  (parent 390)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1080)
  (parent 390)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1081)
  (parent 391)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1082)
  (parent 391)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1083)
  (parent 391)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1084)
  (parent 391)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1085)
  (parent 392)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1086)
  (parent 392)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1087)
  (parent 393)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1088)
  (parent 393)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1089)
  (parent 393)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1090)
  (parent 394)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1091)
  (parent 394)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))))
  (label 1092)
  (parent 394)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1093)
  (parent 394)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1094)
  (parent 395)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1095)
  (parent 395)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1096)
  (parent 396)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1097)
  (parent 397)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1098)
  (parent 397)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1099)
  (parent 398)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1100)
  (parent 398)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1101)
  (parent 399)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1102)
  (parent 400)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1103)
  (parent 400)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1104)
  (parent 401)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1105)
  (parent 401)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1106)
  (parent 401)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1107)
  (parent 402)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1108)
  (parent 402)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-2 nd-0 (pubk a)))))
  (label 1109)
  (parent 402)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1110)
  (parent 405)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1111)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1112)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1113)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1114)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1115)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-2 nd-0 (pubk a)))))
  (label 1116)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1117)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1118)
  (parent 405)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1119)
  (parent 407)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1120)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1121)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1122)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1123)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1124)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-2 nd-0 (pubk a)))))
  (label 1125)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1126)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1127)
  (parent 407)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-2 (pubk c)))))
  (label 1128)
  (parent 410)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1129)
  (parent 410)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1130)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1131)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1132)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1133)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-0 (pubk a)))))
  (label 1134)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1135)
  (parent 410)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-2 (pubk c)))))
  (label 1136)
  (parent 415)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-1 (pubk c)))))
  (label 1137)
  (parent 415)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1138)
  (parent 415)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1139)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1140)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 nb-0 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1141)
  (parent 415)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1142)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nc-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-2) (nb nc-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nc-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-2) (nb nc-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-2) (nb nc-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-2) (nb nc-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-2)
  (operation nonce-test (added-strand resp3 2) nc-2 (0 1)
    (enc a b c nc-2 nc-2 nc-0 (pubk d))
    (enc a b c nc-2 nc-2 nc-1 (pubk d))
    (enc a b c nc-2 nc-2 nc-2 (pubk d)) (enc a b d nc-2 nc-2 (pubk c))
    (enc a b d nc-2 nb-0 (pubk c)) (enc a c d nc-2 (pubk b)))
  (traces
    ((send (enc a c d nc-2 (pubk b)))
      (recv (enc b c d nc-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nc-2 (pubk c))))
    ((recv (enc a b d nc-2 nc-2 (pubk c)))
      (send (enc a b c nc-2 nc-2 nc-0 (pubk d))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nc-2 (pubk c))))
    ((recv (enc a b d nc-2 nc-2 (pubk c)))
      (send (enc a b c nc-2 nc-2 nc-1 (pubk d))))
    ((recv (enc a b d nc-2 nc-2 (pubk c)))
      (send (enc a b c nc-2 nc-2 nc-2 (pubk d))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nb-0 (pubk c))))
    ((recv (enc a b c nc-2 nc-2 nc-2 (pubk d)))
      (send (enc b c d nc-2 nc-2 nc-2 nd-0 (pubk a)))))
  (label 1143)
  (parent 415)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nc-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-1) (nb nc-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nc-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (0 1)
    (enc a b c nc-1 nc-1 nc-0 (pubk d))
    (enc a b c nc-1 nc-1 nc-1 (pubk d))
    (enc a b c nc-1 nc-1 nc-2 (pubk d)) (enc a b d nc-1 nc-1 (pubk c))
    (enc a b d nc-1 nb-0 (pubk c)) (enc a c d nc-1 (pubk b)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-0 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nc-1 (pubk c))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-1 (pubk d))))
    ((recv (enc a b d nc-1 nc-1 (pubk c)))
      (send (enc a b c nc-1 nc-1 nc-2 (pubk d))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b c nc-1 nc-1 nc-1 (pubk d)))
      (send (enc b c d nc-1 nc-1 nc-1 nd-0 (pubk a)))))
  (label 1144)
  (parent 415)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nc-1 nc-2 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nc-1 (pubk d))
    (enc a b c nc-0 nc-0 nc-2 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1145)
  (parent 415)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-0 (pubk a)))))
  (label 1146)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))))
  (label 1147)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (0 1))
    ((2 1) (4 0)) ((3 1) (1 0)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1148)
  (parent 415)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (4 0)
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 1149)
  (parent 416)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nc-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-2) (nb nc-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-2) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-2) (nb nc-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-2) (nb nc-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-2) (nb nc-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-2)
  (operation nonce-test (added-strand resp3 2) nc-2 (4 0)
    (enc a b c nc-2 nc-2 nc-2 (pubk d)) (enc a b d nc-2 nc-2 (pubk c))
    (enc a c d nc-2 (pubk b)))
  (traces
    ((send (enc a c d nc-2 (pubk b)))
      (recv (enc b c d nc-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nc-2 (pubk c))))
    ((recv (enc a b d nc-2 nc-2 (pubk c)))
      (send (enc a b c nc-2 nc-2 nc-0 (pubk d))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nb-0 (pubk c))))
    ((recv (enc a b d nc-2 nb-0 (pubk c)))
      (send (enc a b c nc-2 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-2 nc-2 (pubk c)))
      (send (enc a b c nc-2 nc-2 nc-2 (pubk d))))
    ((recv (enc a c d nc-2 (pubk b)))
      (send (enc a b d nc-2 nc-2 (pubk c))))
    ((recv (enc a b c nc-2 nc-2 nc-2 (pubk d)))
      (send (enc b c d nc-2 nc-2 nc-2 nd-0 (pubk a)))))
  (label 1150)
  (parent 416)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-2 (pubk c)))))
  (label 1151)
  (parent 417)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1152)
  (parent 417)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1153)
  (parent 417)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1154)
  (parent 417)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-3 (pubk d)))))
  (label 1155)
  (parent 417)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-0 (pubk a)))))
  (label 1156)
  (parent 417)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (0 1)
    (enc a b c nb-2 nb-0 nc-0 (pubk d))
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-1 (pubk c)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 1157)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1158)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1159)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 1160)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 1161)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 1162)
  (parent 419)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (0 1)
    (enc a b c nb-2 nb-0 nc-0 (pubk d))
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-1 (pubk c)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 1163)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1164)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1165)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 1166)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 1167)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 1168)
  (parent 422)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (0 1)
    (enc a b c nb-2 nb-0 nc-0 (pubk d))
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-1 (pubk c)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 1169)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1170)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1171)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 1172)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 1173)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 1174)
  (parent 426)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (0 1)
    (enc a b c nb-2 nb-0 nc-0 (pubk d))
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-1 (pubk c)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 1175)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1176)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1177)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 1178)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 1179)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 1180)
  (parent 431)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (0 1)
    (enc a b c nb-2 nb-0 nc-0 (pubk d))
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-1 (pubk c)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 1181)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-0 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1182)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d))
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1183)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 1184)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 1185)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (0 1)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-1 nc-1 (pubk d))
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a)))))
  (label 1186)
  (parent 435)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1187)
  (parent 440)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1188)
  (parent 440)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1189)
  (parent 440)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-1 (4 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1190)
  (parent 441)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1191)
  (parent 441)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-2 (4 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1192)
  (parent 442)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 6 5 resp1 2) nb-2 (4 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1193)
  (parent 442)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1194)
  (parent 442)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1195)
  (parent 443)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1196)
  (parent 443)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1197)
  (parent 443)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1198)
  (parent 443)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1199)
  (parent 444)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1200)
  (parent 444)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-0 nd-0 (pubk a)))))
  (label 1201)
  (parent 444)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1202)
  (parent 444)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1203)
  (parent 445)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1204)
  (parent 446)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1205)
  (parent 446)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1206)
  (parent 446)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d)))))
  (label 1207)
  (parent 446)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1208)
  (parent 447)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-2 (4 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1209)
  (parent 448)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1210)
  (parent 448)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1211)
  (parent 449)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1212)
  (parent 449)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1213)
  (parent 449)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1214)
  (parent 450)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1215)
  (parent 450)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1216)
  (parent 450)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 1 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1217)
  (parent 451)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1218)
  (parent 451)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (3 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1219)
  (parent 451)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1220)
  (parent 452)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1221)
  (parent 452)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1222)
  (parent 452)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1223)
  (parent 453)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1224)
  (parent 453)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1225)
  (parent 453)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1226)
  (parent 454)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1227)
  (parent 454)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1228)
  (parent 454)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (4 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1229)
  (parent 455)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1230)
  (parent 455)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1231)
  (parent 455)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1232)
  (parent 456)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (4 0)
    (enc a b c nb-1 nb-0 nc-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1233)
  (parent 456)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1234)
  (parent 456)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1235)
  (parent 457)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1236)
  (parent 457)
  (unrealized (0 1) (4 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1237)
  (parent 458)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1238)
  (parent 458)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1239)
  (parent 458)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (5 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1240)
  (parent 458)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1241)
  (parent 459)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1242)
  (parent 459)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1243)
  (parent 459)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1244)
  (parent 459)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1245)
  (parent 459)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1246)
  (parent 460)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1247)
  (parent 460)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1248)
  (parent 460)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1249)
  (parent 460)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1250)
  (parent 460)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1251)
  (parent 461)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1252)
  (parent 461)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1253)
  (parent 461)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1254)
  (parent 461)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1255)
  (parent 462)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1256)
  (parent 462)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1257)
  (parent 462)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1258)
  (parent 462)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1259)
  (parent 463)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1260)
  (parent 463)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1261)
  (parent 463)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1262)
  (parent 463)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nc-0 (pubk c))
    (enc a b d nb-1 nb-0 (pubk c)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1263)
  (parent 464)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nc-0 (pubk c))
    (enc a b d nb-1 nb-0 (pubk c)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1264)
  (parent 464)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((0 0) (7 0)) ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nc-0 (pubk c))
    (enc a b d nb-1 nb-0 (pubk c)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a)))))
  (label 1265)
  (parent 464)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1266)
  (parent 465)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1267)
  (parent 465)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1268)
  (parent 465)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 1269)
  (parent 465)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1270)
  (parent 466)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1271)
  (parent 466)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1272)
  (parent 466)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 1273)
  (parent 466)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a)))))
  (label 1274)
  (parent 467)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a)))))
  (label 1275)
  (parent 467)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a)))))
  (label 1276)
  (parent 467)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 1277)
  (parent 467)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 1 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))))
  (label 1278)
  (parent 468)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 3 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))))
  (label 1279)
  (parent 468)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))))
  (label 1280)
  (parent 468)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c)))))
  (label 1281)
  (parent 468)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1282)
  (parent 469)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1283)
  (parent 469)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1284)
  (parent 469)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1285)
  (parent 469)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1286)
  (parent 470)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1287)
  (parent 470)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1288)
  (parent 470)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1289)
  (parent 470)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1290)
  (parent 471)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1291)
  (parent 471)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1292)
  (parent 471)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1293)
  (parent 471)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1294)
  (parent 472)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1295)
  (parent 472)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1296)
  (parent 472)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1297)
  (parent 472)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1298)
  (parent 473)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1299)
  (parent 473)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1300)
  (parent 473)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nd-0 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1301)
  (parent 473)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((1 1) (5 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1302)
  (parent 474)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1303)
  (parent 474)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (4 0)) ((0 0) (6 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1304)
  (parent 474)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1305)
  (parent 475)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-2 (6 0)
    (enc a b d nb-2 nb-0 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1306)
  (parent 475)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1307)
  (parent 475)
  (unrealized (0 1) (4 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-1 (pubk d)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1308)
  (parent 476)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-2 (4 0)
    (enc a b c nb-2 nb-1 nc-1 (pubk d)) (enc a b d nb-2 nb-1 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1309)
  (parent 476)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp2 2) nb-1 (4 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d)))))
  (label 1310)
  (parent 476)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-1 (pubk d)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-1 nd-0 (pubk a)))))
  (label 1311)
  (parent 476)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp1 2) nc-0 (6 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1312)
  (parent 478)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (6 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-2 (pubk c)))))
  (label 1313)
  (parent 478)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (6 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1314)
  (parent 478)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (6 0)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1315)
  (parent 478)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1316)
  (parent 479)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1317)
  (parent 479)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1318)
  (parent 479)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1319)
  (parent 479)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1320)
  (parent 480)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-1 nd-0 (pubk a)))))
  (label 1321)
  (parent 480)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1322)
  (parent 480)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1323)
  (parent 480)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-2 (pubk d)))))
  (label 1324)
  (parent 481)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1325)
  (parent 482)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1326)
  (parent 482)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1327)
  (parent 482)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d)))))
  (label 1328)
  (parent 482)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1329)
  (parent 483)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1330)
  (parent 484)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1331)
  (parent 484)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 3 resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1332)
  (parent 485)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1333)
  (parent 485)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1334)
  (parent 485)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nc-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d)))))
  (label 1335)
  (parent 485)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1336)
  (parent 486)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (5 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1337)
  (parent 487)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1338)
  (parent 488)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1339)
  (parent 488)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1340)
  (parent 488)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1341)
  (parent 489)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1342)
  (parent 489)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1343)
  (parent 491)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1344)
  (parent 491)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1345)
  (parent 491)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1346)
  (parent 491)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1347)
  (parent 491)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1348)
  (parent 492)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1349)
  (parent 492)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1350)
  (parent 492)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1351)
  (parent 492)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1352)
  (parent 492)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1353)
  (parent 492)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1354)
  (parent 493)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1355)
  (parent 494)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1356)
  (parent 494)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1357)
  (parent 494)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1358)
  (parent 495)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1359)
  (parent 495)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1360)
  (parent 495)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1361)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1362)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1363)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1364)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1365)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (6 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0))
    ((4 1) (0 1)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1366)
  (parent 496)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1367)
  (parent 497)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1368)
  (parent 497)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1369)
  (parent 498)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1370)
  (parent 498)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1371)
  (parent 500)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1372)
  (parent 500)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1373)
  (parent 500)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1374)
  (parent 501)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1375)
  (parent 501)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1376)
  (parent 501)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1377)
  (parent 502)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (6 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1378)
  (parent 502)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1379)
  (parent 502)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1380)
  (parent 504)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1381)
  (parent 504)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1382)
  (parent 504)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1383)
  (parent 505)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1384)
  (parent 505)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (2 0)) ((0 0) (5 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1385)
  (parent 505)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-3 (pubk d)))))
  (label 1386)
  (parent 505)
  (unrealized (0 1) (4 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1387)
  (parent 506)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1388)
  (parent 506)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1389)
  (parent 506)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1390)
  (parent 506)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1391)
  (parent 507)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1392)
  (parent 507)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1393)
  (parent 507)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1394)
  (parent 509)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1395)
  (parent 509)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1396)
  (parent 509)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1397)
  (parent 509)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1398)
  (parent 510)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1399)
  (parent 510)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1400)
  (parent 510)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1401)
  (parent 510)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1402)
  (parent 511)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1403)
  (parent 511)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1404)
  (parent 511)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1405)
  (parent 511)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1406)
  (parent 512)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1407)
  (parent 512)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1408)
  (parent 513)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1409)
  (parent 513)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1410)
  (parent 514)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1411)
  (parent 515)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1412)
  (parent 515)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1413)
  (parent 515)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1414)
  (parent 516)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1415)
  (parent 516)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))))
  (label 1416)
  (parent 516)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1417)
  (parent 517)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1418)
  (parent 517)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1419)
  (parent 517)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1420)
  (parent 518)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1421)
  (parent 518)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1422)
  (parent 519)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1423)
  (parent 519)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1424)
  (parent 520)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1425)
  (parent 520)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1426)
  (parent 520)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1427)
  (parent 520)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1428)
  (parent 521)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1429)
  (parent 522)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1430)
  (parent 522)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1431)
  (parent 523)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (6 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1432)
  (parent 523)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 1433)
  (parent 523)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1434)
  (parent 523)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1435)
  (parent 523)
  (unrealized (0 1) (4 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1436)
  (parent 524)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1437)
  (parent 524)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 3 resp1 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1438)
  (parent 525)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (4 0)
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1439)
  (parent 525)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-2 nd-0 (pubk a)))))
  (label 1440)
  (parent 525)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1441)
  (parent 528)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (5 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1442)
  (parent 528)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1443)
  (parent 528)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1444)
  (parent 530)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1445)
  (parent 531)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1446)
  (parent 531)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1447)
  (parent 532)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1448)
  (parent 533)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 1449)
  (parent 533)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1450)
  (parent 534)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1451)
  (parent 534)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1452)
  (parent 534)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a)))))
  (label 1453)
  (parent 535)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1454)
  (parent 535)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1455)
  (parent 536)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1456)
  (parent 536)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1457)
  (parent 536)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1458)
  (parent 537)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1459)
  (parent 537)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1460)
  (parent 538)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1461)
  (parent 538)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1462)
  (parent 538)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1463)
  (parent 539)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1464)
  (parent 539)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1465)
  (parent 539)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (0 1)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1466)
  (parent 539)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1467)
  (parent 540)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1468)
  (parent 540)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (4 0))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 5 3 resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1469)
  (parent 540)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (4 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1470)
  (parent 540)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a)))))
  (label 1471)
  (parent 541)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1472)
  (parent 541)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nc-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nc-0 (pubk a)))))
  (label 1473)
  (parent 541)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1474)
  (parent 541)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1475)
  (parent 541)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1476)
  (parent 542)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1477)
  (parent 543)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1478)
  (parent 543)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1479)
  (parent 543)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1480)
  (parent 544)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1481)
  (parent 544)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1482)
  (parent 544)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1483)
  (parent 545)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1484)
  (parent 545)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1485)
  (parent 545)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1486)
  (parent 546)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1487)
  (parent 546)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1488)
  (parent 547)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1489)
  (parent 547)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1490)
  (parent 548)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1491)
  (parent 548)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1492)
  (parent 548)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1493)
  (parent 548)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1494)
  (parent 549)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1495)
  (parent 549)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1496)
  (parent 549)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1497)
  (parent 549)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1498)
  (parent 550)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1499)
  (parent 551)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1500)
  (parent 551)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1501)
  (parent 551)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1502)
  (parent 551)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1503)
  (parent 552)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (5 0)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 3 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1504)
  (parent 552)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1505)
  (parent 552)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1506)
  (parent 553)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1507)
  (parent 554)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1508)
  (parent 554)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1509)
  (parent 554)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1510)
  (parent 554)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1511)
  (parent 555)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1512)
  (parent 555)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1513)
  (parent 555)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1514)
  (parent 555)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1515)
  (parent 556)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1516)
  (parent 556)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1517)
  (parent 556)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1518)
  (parent 556)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1519)
  (parent 557)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1520)
  (parent 557)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1521)
  (parent 557)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1522)
  (parent 557)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1523)
  (parent 558)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1524)
  (parent 558)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1525)
  (parent 558)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1526)
  (parent 558)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1527)
  (parent 559)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))))
  (label 1528)
  (parent 559)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (0 1))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1529)
  (parent 559)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1530)
  (parent 560)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((3 1) (4 0)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1531)
  (parent 560)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1532)
  (parent 560)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1533)
  (parent 560)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1534)
  (parent 561)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (displaced 7 6 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c)))))
  (label 1535)
  (parent 561)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (0 1))
    ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1536)
  (parent 561)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1537)
  (parent 561)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1538)
  (parent 562)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a)))))
  (label 1539)
  (parent 562)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))))
  (label 1540)
  (parent 562)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1541)
  (parent 563)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1542)
  (parent 563)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1543)
  (parent 563)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1544)
  (parent 563)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1545)
  (parent 564)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1546)
  (parent 564)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1547)
  (parent 564)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1548)
  (parent 564)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1549)
  (parent 564)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-2 nb-1)) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1550)
  (parent 565)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1551)
  (parent 565)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1552)
  (parent 566)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1553)
  (parent 566)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1554)
  (parent 566)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1555)
  (parent 566)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1556)
  (parent 567)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1557)
  (parent 568)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1558)
  (parent 568)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1559)
  (parent 569)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1560)
  (parent 569)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1561)
  (parent 569)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1562)
  (parent 569)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1563)
  (parent 570)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-2 (5 0)
    (enc a b d nb-2 nb-1 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1564)
  (parent 571)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nd-0 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1565)
  (parent 571)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1566)
  (parent 572)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1567)
  (parent 572)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1568)
  (parent 572)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1569)
  (parent 572)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1570)
  (parent 572)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1571)
  (parent 572)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1572)
  (parent 573)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1573)
  (parent 573)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1574)
  (parent 573)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1575)
  (parent 574)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1576)
  (parent 574)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1577)
  (parent 574)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1578)
  (parent 575)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1579)
  (parent 575)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1580)
  (parent 576)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1581)
  (parent 576)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1582)
  (parent 576)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1583)
  (parent 576)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1584)
  (parent 576)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1585)
  (parent 576)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1586)
  (parent 577)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-0 (pubk a)))))
  (label 1587)
  (parent 577)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))))
  (label 1588)
  (parent 577)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nb-0 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))))
  (label 1589)
  (parent 577)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1590)
  (parent 578)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a)))))
  (label 1591)
  (parent 578)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1592)
  (parent 578)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1593)
  (parent 580)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nd text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nd (pubk d))
    (enc a b d nb nb (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d)))))
  (label 1594)
  (parent 581)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1595)
  (parent 581)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1596)
  (parent 581)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 5 resp1 2) nb-1 (4 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 1597)
  (parent 582)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1598)
  (parent 582)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1599)
  (parent 582)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd text) (a b c d name))
  (defstrand init 3 (na nc) (nb nc) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc) (nb nc) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc) (nb nc) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc)
  (operation nonce-test (contracted (nb nc) (nc-0 nc) (nd-0 nd)) nc
    (0 1) (enc a b c nc nc nc (pubk d)) (enc a b d nc nc (pubk c))
    (enc a c d nc (pubk b)) (enc b c d nc nc nc nd (pubk a)))
  (traces
    ((send (enc a c d nc (pubk b)))
      (recv (enc b c d nc nc nc nd (pubk a)))
      (send (enc nc nc nd (pubk b))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nc (pubk c))))
    ((recv (enc a b d nc nc (pubk c)))
      (send (enc a b c nc nc nc (pubk d))))
    ((recv (enc a b c nc nc nc (pubk d)))
      (send (enc b c d nc nc nc nd (pubk a)))))
  (label 1600)
  (parent 583)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d)))))
  (label 1601)
  (parent 583)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nc-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nc-0 (pubk a)))))
  (label 1602)
  (parent 583)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1603)
  (parent 584)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 1604)
  (parent 585)
  (unrealized (0 1) (3 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb nc text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d)))))
  (label 1605)
  (parent 586)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1606)
  (parent 586)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1607)
  (parent 586)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1608)
  (parent 586)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1609)
  (parent 586)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1610)
  (parent 587)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1611)
  (parent 588)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1612)
  (parent 588)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nd-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nd-0 (pubk c)))
      (send (enc a b c nc-0 nd-0 nc-1 (pubk d)))))
  (label 1613)
  (parent 591)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nd-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 4 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nd-0 (pubk c)))
      (send (enc a b c nc-0 nd-0 nc-1 (pubk d)))))
  (label 1614)
  (parent 591)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nd-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nd-0 (pubk c)))
      (send (enc a b c nc-0 nd-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1615)
  (parent 591)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1616)
  (parent 592)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 4 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1617)
  (parent 592)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1618)
  (parent 592)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 1619)
  (parent 593)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 6 4 resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 1620)
  (parent 593)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp1 2) nc-0 (5 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nd-0 (pubk c))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c)))))
  (label 1621)
  (parent 593)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 2 resp2 2) nb-0 (5 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c)))))
  (label 1622)
  (parent 594)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 text) (a b c d name))
  (defstrand init 3 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc) (nb nb) (nc nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc)
  (operation nonce-test (contracted (nb-0 nb) (nc-1 nc) (nd-0 nd)) nc
    (0 1) (enc a b c nc nb nc (pubk d)) (enc a b c nc nb nc-0 (pubk d))
    (enc a b d nc nb (pubk c)) (enc a c d nc (pubk b))
    (enc b c d nc nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nc (pubk b)))
      (recv (enc b c d nc nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc (pubk b))) (send (enc a b d nc nb (pubk c))))
    ((recv (enc a b d nc nb (pubk c)))
      (send (enc a b c nc nb nc (pubk d))))
    ((recv (enc a b c nc nb nc (pubk d)))
      (send (enc b c d nc nb nc nd (pubk a))))
    ((recv (enc a b d nc nb (pubk c)))
      (send (enc a b c nc nb nc-0 (pubk d)))))
  (label 1623)
  (parent 595)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1624)
  (parent 595)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 1625)
  (parent 595)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1626)
  (parent 595)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nb-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nb-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-1 nd-1 (pubk a)))))
  (label 1627)
  (parent 595)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (contracted (nb-1 nb-0)) nc-0 (4 0)
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c)))))
  (label 1628)
  (parent 596)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (4 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-2 (pubk d)))))
  (label 1629)
  (parent 596)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nd-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nd-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nd-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nd-0) (nb nb-0) (nc nd-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nd-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nd-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (4 0)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nd-0)
  (operation nonce-test (displaced 6 3 resp3 2) nc-1 (4 0)
    (enc a b d nc-1 nb-1 (pubk c)) (enc a c d nc-1 (pubk b)))
  (traces
    ((send (enc a c d nd-0 (pubk b)))
      (recv (enc b c d nd-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nd-0 (pubk b)))
      (send (enc a b d nd-0 nb-0 (pubk c))))
    ((recv (enc a b d nd-0 nb-0 (pubk c)))
      (send (enc a b c nd-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nd-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nd-0 nb-0 nd-0 nd-0 (pubk a))))
    ((recv (enc a b d nd-0 nb-0 (pubk c)))
      (send (enc a b c nd-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nd-0 (pubk b)))
      (send (enc a b d nd-0 nb-1 (pubk c)))))
  (label 1630)
  (parent 596)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((2 1) (3 0)) ((2 1) (4 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 5 2 resp2 2) nc-0 (4 0)
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a)))))
  (label 1631)
  (parent 597)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (4 0)
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1632)
  (parent 597)
  (unrealized (0 1) (4 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 1 resp1 2) nc-0 (4 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1633)
  (parent 598)
  (unrealized (0 1) (4 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (0 1)) ((5 1) (4 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (4 0)
    (enc a b d nc-0 nb-1 (pubk c)) (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nb-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b d nc-0 nb-1 (pubk c)))
      (send (enc a b c nc-0 nb-1 nc-1 (pubk d)))))
  (label 1634)
  (parent 598)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1635)
  (parent 599)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 4 resp2 2) na (5 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1636)
  (parent 599)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nd-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-2) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (5 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-2 (pubk a)))))
  (label 1637)
  (parent 599)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1638)
  (parent 600)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 6 2 resp2 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)) (enc b c d na nb-0 nc-1 nd-1 (pubk a)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1639)
  (parent 600)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nd-2 text) (a b c d name))
  (defstrand init 3 (na nc-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nc-1) (nb nb-0) (nc nc-1) (nd nd-2) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-1)
  (operation nonce-test (added-strand resp3 2) nc-1 (3 0)
    (enc a b c nc-1 nb-0 nc-1 (pubk d)) (enc a b d nc-1 nb-0 (pubk c))
    (enc a c d nc-1 (pubk b)) (enc b c d nc-1 nb-0 nc-1 nd-1 (pubk a)))
  (traces
    ((send (enc a c d nc-1 (pubk b)))
      (recv (enc b c d nc-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-1 (pubk b)))
      (send (enc a b d nc-1 nb-0 (pubk c))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-1 nb-0 (pubk c)))
      (send (enc a b c nc-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-1 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b c nc-1 nb-0 nc-1 (pubk d)))
      (send (enc b c d nc-1 nb-0 nc-1 nd-2 (pubk a)))))
  (label 1640)
  (parent 600)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nd-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-2) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-2 (pubk a)))))
  (label 1641)
  (parent 600)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1642)
  (parent 601)
  (unrealized (0 1) (3 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nc-2 nb-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (7 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 1643)
  (parent 601)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1644)
  (parent 602)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1645)
  (parent 602)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1646)
  (parent 602)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1647)
  (parent 602)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nd nc nb text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (2 0)) ((4 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation generalization deleted (2 0))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c))))
    ((recv (enc a b c na nb nc (pubk d)))
      (send (enc b c d na nb nc nd (pubk a))))
    ((recv (enc a b d na nb (pubk c)))
      (send (enc a b c na nb nc (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb (pubk c)))))
  (label 1648)
  (parent 604)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 4 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c)))))
  (label 1649)
  (parent 606)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c)))))
  (label 1650)
  (parent 610)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 1 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1651)
  (parent 612)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1652)
  (parent 612)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 1653)
  (parent 612)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1654)
  (parent 613)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (4 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1655)
  (parent 613)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1656)
  (parent 613)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0)) ((5 1) (6 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1657)
  (parent 614)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (4 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 4 resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1658)
  (parent 614)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((5 1) (6 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1659)
  (parent 614)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-0 nc-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1660)
  (parent 616)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1661)
  (parent 616)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 1662)
  (parent 616)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-2 (pubk d)))
      (send (enc b c d na nb-1 nc-2 nd-1 (pubk a)))))
  (label 1663)
  (parent 616)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1664)
  (parent 616)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 5 resp1 2) na (6 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 1665)
  (parent 617)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1666)
  (parent 617)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (4 0))
    ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (6 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-1 (pubk a)))))
  (label 1667)
  (parent 617)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nd-0 nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nc-2 nc-0)) na (3 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 1668)
  (parent 619)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nd-0 nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nc-2 nc-1)) na (3 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 1669)
  (parent 619)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1670)
  (parent 619)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0)) ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d)))))
  (label 1671)
  (parent 619)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-1 (pubk a)))))
  (label 1672)
  (parent 619)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nc-2 nd-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-0 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1673)
  (parent 619)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nd-0 nc-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-2 nc-1)) na (3 0)
    (enc a b c na nb-0 nc-0 (pubk d)) (enc a b c na nb-0 nc-1 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d)))))
  (label 1674)
  (parent 620)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (3 0)
    (enc a b c nb-1 nb-0 nc-1 (pubk d))
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 1675)
  (parent 620)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1676)
  (parent 620)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((1 1) (2 0)) ((1 1) (4 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (displaced 7 2 resp2 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 1677)
  (parent 620)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-2 (pubk d)))
      (send (enc b c d na nb-1 nc-2 nd-1 (pubk a)))))
  (label 1678)
  (parent 620)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (3 0)
    (enc a b c na nb-0 nc-1 (pubk d)) (enc a b c na nb-1 nc-2 (pubk d))
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a)))))
  (label 1679)
  (parent 620)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1680)
  (parent 623)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 1681)
  (parent 624)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1682)
  (parent 624)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1683)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1684)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1685)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1686)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1687)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1688)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1689)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1690)
  (parent 624)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1691)
  (parent 625)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1692)
  (parent 625)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1693)
  (parent 625)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1694)
  (parent 626)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1695)
  (parent 626)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1696)
  (parent 626)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 1697)
  (parent 627)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1698)
  (parent 627)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1699)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1700)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1701)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1702)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1703)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1704)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1705)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1706)
  (parent 627)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1707)
  (parent 628)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1708)
  (parent 628)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1709)
  (parent 628)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1710)
  (parent 629)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (5 0))
    ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1711)
  (parent 629)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1712)
  (parent 629)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1713)
  (parent 630)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1714)
  (parent 630)
  (unrealized (0 1) (3 0) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1715)
  (parent 630)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-1 (5 0)
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1716)
  (parent 630)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-1 (pubk a)))))
  (label 1717)
  (parent 630)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1718)
  (parent 631)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1719)
  (parent 631)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1720)
  (parent 631)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb nc text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((1 1) (2 0)) ((2 1) (0 1))
    ((3 1) (4 0)) ((4 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation generalization deleted (2 0))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d)))))
  (label 1721)
  (parent 633)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb nc nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-0 (pubk c)))))
  (label 1722)
  (parent 634)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1723)
  (parent 634)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1724)
  (parent 634)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1725)
  (parent 634)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1726)
  (parent 634)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1727)
  (parent 634)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1728)
  (parent 635)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1729)
  (parent 635)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1730)
  (parent 635)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1731)
  (parent 636)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1732)
  (parent 636)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1733)
  (parent 636)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d)))))
  (label 1734)
  (parent 637)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nc (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c)))))
  (label 1735)
  (parent 639)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1736)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1737)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1738)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1739)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1740)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1741)
  (parent 639)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1742)
  (parent 640)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1743)
  (parent 640)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1744)
  (parent 640)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1745)
  (parent 641)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1746)
  (parent 641)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1747)
  (parent 641)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1748)
  (parent 642)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1749)
  (parent 642)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1750)
  (parent 642)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1751)
  (parent 643)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1752)
  (parent 643)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1753)
  (parent 643)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1754)
  (parent 644)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1755)
  (parent 644)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1756)
  (parent 644)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d)))))
  (label 1757)
  (parent 645)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1758)
  (parent 646)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0)) ((5 1) (3 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1759)
  (parent 646)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1760)
  (parent 646)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-2 nc-0)) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1761)
  (parent 647)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-2 (pubk c)))))
  (label 1762)
  (parent 647)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1763)
  (parent 647)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1764)
  (parent 647)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 nc-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-1 (pubk d))
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 1765)
  (parent 647)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1766)
  (parent 647)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (3 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-1 (pubk a)))))
  (label 1767)
  (parent 647)
  (unrealized (0 1) (3 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1768)
  (parent 648)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1769)
  (parent 648)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((4 1) (6 0)) ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 1770)
  (parent 648)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1771)
  (parent 650)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1772)
  (parent 650)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (6 0))
    ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0)) ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1773)
  (parent 650)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1774)
  (parent 650)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (3 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (6 0))
    ((6 1) (3 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1775)
  (parent 651)
  (unrealized (0 1) (3 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((4 1) (6 0)) ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1776)
  (parent 651)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb-0 (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nc (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb-0 (pubk d)))))
  (label 1777)
  (parent 654)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1778)
  (parent 654)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1779)
  (parent 654)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1780)
  (parent 654)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1781)
  (parent 654)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 1782)
  (parent 654)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a b d nb-1 nb-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1783)
  (parent 655)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1784)
  (parent 655)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1785)
  (parent 655)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1786)
  (parent 655)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a b d nb-1 nc-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1787)
  (parent 656)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1788)
  (parent 656)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1789)
  (parent 656)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nc (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d)))))
  (label 1790)
  (parent 658)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1791)
  (parent 658)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1792)
  (parent 658)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1793)
  (parent 658)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1794)
  (parent 658)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1795)
  (parent 659)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1796)
  (parent 659)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1797)
  (parent 659)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-1 (6 0)
    (enc a b d nb-1 nc-0 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d)))))
  (label 1798)
  (parent 660)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1799)
  (parent 660)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1800)
  (parent 660)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1801)
  (parent 662)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1802)
  (parent 662)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1803)
  (parent 662)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1804)
  (parent 662)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1805)
  (parent 662)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nc (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 1806)
  (parent 663)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1807)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1808)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nc-0 (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1809)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1810)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1811)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1812)
  (parent 663)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nc-0)) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1813)
  (parent 664)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1814)
  (parent 664)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-2 (pubk d)))))
  (label 1815)
  (parent 664)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1816)
  (parent 666)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1817)
  (parent 666)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1818)
  (parent 666)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((2 1) (6 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1819)
  (parent 666)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1820)
  (parent 666)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (6 0)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 5 resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d)))))
  (label 1821)
  (parent 667)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (6 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1822)
  (parent 667)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nc) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nc) (nc nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nc nc-0 (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nc (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nc (pubk c))))
    ((recv (enc a b d nb nc (pubk c)))
      (send (enc a b c nb nc nc-0 (pubk d)))))
  (label 1823)
  (parent 668)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1824)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1825)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nd-0 (pubk d)))))
  (label 1826)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp2 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-2 (pubk d)))))
  (label 1827)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-2 (pubk d)))))
  (label 1828)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1829)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1830)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nc-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nc-0 nc-1 (pubk d)))
      (send (enc b c d nb-0 nc-0 nc-1 nd-1 (pubk a)))))
  (label 1831)
  (parent 668)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((1 1) (2 0)) ((1 1) (4 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation generalization deleted (4 0))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb-0 (pubk d)))))
  (label 1832)
  (parent 670)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1833)
  (parent 671)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1834)
  (parent 671)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1835)
  (parent 671)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1836)
  (parent 672)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1837)
  (parent 672)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1838)
  (parent 672)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1839)
  (parent 673)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1840)
  (parent 673)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1841)
  (parent 673)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 2 resp2 2) nc-0 (6 0)
    (enc a c d nc-0 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d)))))
  (label 1842)
  (parent 674)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 1843)
  (parent 675)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 1844)
  (parent 675)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1845)
  (parent 675)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd nb text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb (pubk d))
    (enc a b d nb nb (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d)))))
  (label 1846)
  (parent 676)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1847)
  (parent 676)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1848)
  (parent 676)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb-0 (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb-0 (pubk d)))))
  (label 1849)
  (parent 677)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1850)
  (parent 677)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1851)
  (parent 677)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1852)
  (parent 677)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1853)
  (parent 677)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 1854)
  (parent 677)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1855)
  (parent 678)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1856)
  (parent 678)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1857)
  (parent 678)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd nb nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-0 (pubk c)))))
  (label 1858)
  (parent 679)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1859)
  (parent 679)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1860)
  (parent 679)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1861)
  (parent 679)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1862)
  (parent 679)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1863)
  (parent 679)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd nb nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb-0) (nc nc) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-0 nc) (nd-0 nd))
    nb-0 (0 1) (enc a b c nb-0 nb-0 nc (pubk d))
    (enc a b c nb-0 nb-0 nb (pubk d)) (enc a b d nb-0 nb (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc nd (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb-0 nc nd (pubk a)))
      (send (enc nb-0 nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc (pubk d)))
      (send (enc b c d nb-0 nb-0 nc nd (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 1864)
  (parent 680)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c)))))
  (label 1865)
  (parent 680)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d)))))
  (label 1866)
  (parent 680)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nb-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d)))))
  (label 1867)
  (parent 680)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1868)
  (parent 680)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1869)
  (parent 680)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-0 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-0 nd-1 (pubk a)))))
  (label 1870)
  (parent 680)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-2 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d)) (enc a b c nb nb nb-0 (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a b d nb nb-1 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb-0 (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-1 (pubk c)))))
  (label 1871)
  (parent 681)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1872)
  (parent 681)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1873)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1874)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1875)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1876)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1877)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nc-0 nb-0 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a b d nc-0 nb-1 (pubk c))
    (enc a c d nc-0 (pubk b)) (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-1 (pubk c))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1878)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-1 (pubk a)))))
  (label 1879)
  (parent 681)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1880)
  (parent 684)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1881)
  (parent 684)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1882)
  (parent 685)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1883)
  (parent 685)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1884)
  (parent 685)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1885)
  (parent 686)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1886)
  (parent 686)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1887)
  (parent 686)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d)))))
  (label 1888)
  (parent 687)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1889)
  (parent 687)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1890)
  (parent 687)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1891)
  (parent 687)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1892)
  (parent 687)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1893)
  (parent 688)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1894)
  (parent 688)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1895)
  (parent 688)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nc nd nb nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb-0) (nc nc) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc-0 nc) (nd-0 nd))
    nb-0 (0 1) (enc a b c nb-0 nb-0 nc (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc nd (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb-0 nc nd (pubk a)))
      (send (enc nb-0 nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc (pubk d)))
      (send (enc b c d nb-0 nb-0 nc nd (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 1896)
  (parent 689)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nc-0 (pubk c)))))
  (label 1897)
  (parent 689)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 1898)
  (parent 689)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d)))))
  (label 1899)
  (parent 689)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d)))))
  (label 1900)
  (parent 689)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nc-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-1 (pubk a)))))
  (label 1901)
  (parent 689)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-2 nb) (nc-0 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nc (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a b d nb nb-1 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-1 (pubk c)))))
  (label 1902)
  (parent 690)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c)))))
  (label 1903)
  (parent 690)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1904)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1905)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1906)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 1907)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1908)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-1 (pubk a)))))
  (label 1909)
  (parent 690)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nd (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nd (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nd (pubk c)))))
  (label 1910)
  (parent 693)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1911)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1912)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nd-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b d nb-0 nd-0 (pubk c)))
      (send (enc a b c nb-0 nd-0 nc-0 (pubk d)))))
  (label 1913)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1914)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1915)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nd-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1916)
  (parent 693)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1917)
  (parent 694)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1918)
  (parent 694)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1919)
  (parent 695)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1920)
  (parent 695)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1921)
  (parent 695)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1922)
  (parent 696)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1923)
  (parent 696)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1924)
  (parent 696)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1925)
  (parent 697)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1926)
  (parent 697)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1927)
  (parent 697)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((1 1) (6 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1928)
  (parent 698)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1929)
  (parent 698)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1930)
  (parent 698)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-0 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nd (pubk d)) (enc a b c nb nb nb (pubk d))
    (enc a b d nb nb (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d)))))
  (label 1931)
  (parent 699)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1932)
  (parent 699)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1933)
  (parent 699)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1934)
  (parent 699)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nd nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nd (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d)))))
  (label 1935)
  (parent 700)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c)))))
  (label 1936)
  (parent 700)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1937)
  (parent 700)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1938)
  (parent 700)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1939)
  (parent 700)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1940)
  (parent 700)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1941)
  (parent 700)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1942)
  (parent 701)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1943)
  (parent 701)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1944)
  (parent 701)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb nb-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nd (pubk d)) (enc a b c nb nb nb (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a c d nb (pubk b)) (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-0 (pubk c)))))
  (label 1945)
  (parent 702)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c)))))
  (label 1946)
  (parent 702)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1947)
  (parent 702)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1948)
  (parent 702)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1949)
  (parent 702)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1950)
  (parent 702)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nd-0 (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1951)
  (parent 702)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nd nb nb-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb-0) (nc nb-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-1 nb-0) (nc nb-0) (nd-0 nd))
    nb-0 (0 1) (enc a b c nb-0 nb-0 nd (pubk d))
    (enc a b c nb-0 nb-0 nb-0 (pubk d)) (enc a b d nb-0 nb (pubk c))
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb-0 nb-0 nd (pubk a)))
      (send (enc nb-0 nb-0 nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c)))))
  (label 1952)
  (parent 703)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp1 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nd-0 (pubk c)))))
  (label 1953)
  (parent 703)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-0 (pubk d)))))
  (label 1954)
  (parent 703)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d)))))
  (label 1955)
  (parent 703)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nb-0 (pubk a)))))
  (label 1956)
  (parent 703)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nb-1 (pubk a)))))
  (label 1957)
  (parent 703)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nb-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp3 2) nb-1 (0 1)
    (enc a b c nb-1 nb-1 nd-0 (pubk d))
    (enc a b c nb-1 nb-1 nb-1 (pubk d)) (enc a b d nb-1 nb-0 (pubk c))
    (enc a b d nb-1 nb-1 (pubk c)) (enc a c d nb-1 (pubk b))
    (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nb-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nb-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b c nb-1 nb-1 nd-0 (pubk d)))
      (send (enc b c d nb-1 nb-1 nd-0 nd-1 (pubk a)))))
  (label 1958)
  (parent 703)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nd nb-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nb) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nb) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nd) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-2 nb) (nc nb) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nb (pubk d)) (enc a b c nb nb nd (pubk d))
    (enc a b d nb nb (pubk c)) (enc a b d nb nb-0 (pubk c))
    (enc a b d nb nb-1 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nb nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nb nd (pubk a)))
      (send (enc nb nb nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nb (pubk d))))
    ((recv (enc a b c nb nb nb (pubk d)))
      (send (enc b c d nb nb nb nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nd (pubk d))))
    ((recv (enc a c d nb (pubk b)))
      (send (enc a b d nb nb-1 (pubk c)))))
  (label 1959)
  (parent 704)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nd-0) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nd-0 (pubk c)))))
  (label 1960)
  (parent 704)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 1961)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1962)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 1963)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d)))))
  (label 1964)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-2) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-2 (pubk a)))))
  (label 1965)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-1 (pubk a)))))
  (label 1966)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nb-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nb-0 (pubk a)))))
  (label 1967)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nd-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-0 nd-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b c nb-0 nb-0 nd-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nd-0 nd-1 (pubk a)))))
  (label 1968)
  (parent 704)
  (unrealized (0 1) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb) (nc nc) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na nb) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb)
  (operation nonce-test (contracted (nb-1 nb) (nc-1 nc) (nd-0 nd)) nb
    (0 1) (enc a b c nb nb nc (pubk d))
    (enc a b c nb nb-0 nc-0 (pubk d)) (enc a b d nb nb (pubk c))
    (enc a b d nb nb-0 (pubk c)) (enc a c d nb (pubk b))
    (enc b c d nb nb nc nd (pubk a)))
  (traces
    ((send (enc a c d nb (pubk b)))
      (recv (enc b c d nb nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb (pubk c))))
    ((recv (enc a b d nb nb (pubk c)))
      (send (enc a b c nb nb nc (pubk d))))
    ((recv (enc a b c nb nb nc (pubk d)))
      (send (enc b c d nb nb nc nd (pubk a))))
    ((recv (enc a c d nb (pubk b))) (send (enc a b d nb nb-0 (pubk c))))
    ((recv (enc a b d nb nb-0 (pubk c)))
      (send (enc a b c nb nb-0 nc-0 (pubk d)))))
  (label 1969)
  (parent 706)
  (unrealized)
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1970)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1971)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-1 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1972)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nb-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1973)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)) (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1974)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nc-0 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nc-0 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 1975)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (added-strand resp3 2) nc-0 (0 1)
    (enc a b c nc-0 nc-0 nc-0 (pubk d))
    (enc a b c nc-0 nb-0 nc-1 (pubk d)) (enc a b d nc-0 nc-0 (pubk c))
    (enc a b d nc-0 nb-0 (pubk c)) (enc a c d nc-0 (pubk b))
    (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nc-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-1 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nc-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nc-0 nd-1 (pubk a)))))
  (label 1976)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((4 1) (5 0)) ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (0 1)
    (enc a b c nb-0 nb-0 nc-0 (pubk d))
    (enc a b c nb-0 nb-1 nc-1 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b))
    (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a)))))
  (label 1977)
  (parent 706)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (contracted (nb-2 nb-1)) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-1 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 1978)
  (parent 707)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 1979)
  (parent 707)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 2 resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1980)
  (parent 707)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1981)
  (parent 707)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 6 4 resp1 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d)))))
  (label 1982)
  (parent 708)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1983)
  (parent 708)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((2 1) (5 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (5 0)
    (enc a b c nb-0 nb-0 nc-0 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-1 (pubk a)))))
  (label 1984)
  (parent 708)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((5 1) (0 1))
    ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1985)
  (parent 709)
  (unrealized (0 1) (5 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (5 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 1986)
  (parent 709)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1987)
  (parent 709)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d)))))
  (label 1988)
  (parent 711)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1989)
  (parent 711)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 1990)
  (parent 712)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1991)
  (parent 712)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1992)
  (parent 713)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1993)
  (parent 713)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d)))))
  (label 1994)
  (parent 713)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-1 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1995)
  (parent 713)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nd-0 nb-0 nc-0 text) (a b c d name))
  (defstrand init 3 (na nc-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nc-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nc-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nc-0) (nb nc-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nc-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nc-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (6 0))
    ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nc-0)
  (operation nonce-test (displaced 7 5 resp2 2) nb-1 (6 0)
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nc-0 (pubk b)))
      (recv (enc b c d nc-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nc-0 (pubk c))))
    ((recv (enc a b d nc-0 nc-0 (pubk c)))
      (send (enc a b c nc-0 nc-0 nb-0 (pubk d))))
    ((recv (enc a b c nc-0 nc-0 nb-0 (pubk d)))
      (send (enc b c d nc-0 nc-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nc-0 (pubk b)))
      (send (enc a b d nc-0 nb-0 (pubk c))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nc-0 nb-0 (pubk c)))
      (send (enc a b c nc-0 nb-0 nd-0 (pubk d)))))
  (label 1996)
  (parent 713)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d)))))
  (label 1997)
  (parent 714)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nc-0 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 1998)
  (parent 714)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nc-0 nd-0 nb-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((5 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-1 (pubk d)))))
  (label 1999)
  (parent 715)
  (unrealized (0 1))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((1 1) (6 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 1 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 2000)
  (parent 716)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((1 1) (2 0)) ((2 1) (3 0))
    ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0)) ((4 1) (6 0))
    ((5 1) (0 1)) ((6 1) (0 1)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (displaced 7 4 resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a)))))
  (label 2001)
  (parent 716)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nc-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0)) ((4 1) (5 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nc-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c)))))
  (label 2002)
  (parent 716)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-3 (pubk c)))))
  (label 69)
  (parent 27)
  (unrealized (0 1) (2 0) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 112)
  (parent 47)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-3 (pubk d)))))
  (label 126)
  (parent 54)
  (unrealized (0 1) (4 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 144)
  (parent 62)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 154)
  (parent 64)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 159)
  (parent 66)
  (unrealized (0 1) (4 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 161)
  (parent 67)
  (unrealized (0 1) (2 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (4 0)
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-2 (pubk c))
    (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 164)
  (parent 68)
  (unrealized (0 1) (2 0) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 165)
  (parent 68)
  (unrealized (0 1) (2 0) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 229)
  (parent 91)
  (unrealized (0 1) (3 0) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 237)
  (parent 94)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 273)
  (parent 106)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0)) ((5 1) (3 0))
    ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 285)
  (parent 110)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 286)
  (parent 111)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1))
    ((4 1) (3 0)) ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 288)
  (parent 111)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 300)
  (parent 116)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 307)
  (parent 119)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nd-0 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b c na nb-0 nc-2 (pubk d)))
      (send (enc b c d na nb-0 nc-2 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 316)
  (parent 122)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nc-3 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (4 0))
    ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0)) ((5 1) (4 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 324)
  (parent 124)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-3 (pubk d)))))
  (label 326)
  (parent 125)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 327)
  (parent 125)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 345)
  (parent 131)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d)))))
  (label 352)
  (parent 134)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (5 0))
    ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0)) ((5 1) (2 0))
    ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 368)
  (parent 139)
  (unrealized (0 1) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (7 0)) ((1 1) (0 1))
    ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-2 (pubk c)))))
  (label 375)
  (parent 141)
  (unrealized (0 1) (2 0) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 377)
  (parent 142)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a b d nb-0 nb-2 (pubk c))
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d)))))
  (label 378)
  (parent 142)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d)))))
  (label 379)
  (parent 143)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nd-0 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((3 1) (5 0))
    ((4 1) (2 0)) ((5 1) (2 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (5 0)
    (enc a b d nb-1 nb-1 (pubk c)) (enc a b d nb-1 nb-2 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-1 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-1 nb-1 nc-1 nd-0 (pubk a))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d)))))
  (label 381)
  (parent 143)
  (unrealized (0 1) (2 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 403)
  (parent 151)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-0 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 404)
  (parent 151)
  (unrealized (0 1) (4 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (6 0)
    (enc a b d nb-0 nb-1 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-3 (pubk d)))))
  (label 406)
  (parent 152)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-3 (pubk d)))))
  (label 408)
  (parent 153)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-2 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-2 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-2 nc-2 nd-0 (pubk a)))))
  (label 409)
  (parent 153)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-2 (pubk d)))))
  (label 411)
  (parent 155)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d)))))
  (label 412)
  (parent 155)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-3 (pubk d)))))
  (label 413)
  (parent 155)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp3 2) nb-0 (4 0)
    (enc a b c nb-0 nb-0 nc-2 (pubk d)) (enc a b d nb-0 nb-0 (pubk c))
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-2 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-2 nd-0 (pubk a)))))
  (label 414)
  (parent 155)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nc-2 nb-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-3 (pubk d)))))
  (label 418)
  (parent 156)
  (unrealized (0 1) (4 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-3 (pubk d)))))
  (label 420)
  (parent 157)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 421)
  (parent 157)
  (unrealized (0 1) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (4 0)
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-2 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 423)
  (parent 158)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 424)
  (parent 158)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 425)
  (parent 158)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (2 0)
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-1 (pubk c))
    (enc a b d nb-2 nb-2 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 427)
  (parent 160)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 428)
  (parent 160)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 429)
  (parent 160)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (6 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 430)
  (parent 160)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (4 0)
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-0 (pubk c))
    (enc a b d nb-2 nb-2 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 432)
  (parent 162)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 433)
  (parent 162)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (2 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (4 0)
    (enc a b c na nb-2 nc-2 (pubk d)) (enc a b d na nb-0 (pubk c))
    (enc a b d na nb-2 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 434)
  (parent 162)
  (unrealized (0 1) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-2) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-2) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-2) (nb nb-2) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-2)
  (operation nonce-test (added-strand resp2 2) nb-2 (2 0)
    (enc a b c nb-2 nb-1 nc-1 (pubk d))
    (enc a b c nb-2 nb-2 nc-2 (pubk d)) (enc a b d nb-2 nb-1 (pubk c))
    (enc a b d nb-2 nb-2 (pubk c)) (enc a c d nb-2 (pubk b)))
  (traces
    ((send (enc a c d nb-2 (pubk b)))
      (recv (enc b c d nb-2 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-0 (pubk c))))
    ((recv (enc a b d nb-2 nb-0 (pubk c)))
      (send (enc a b c nb-2 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-1 (pubk c))))
    ((recv (enc a b d nb-2 nb-1 (pubk c)))
      (send (enc a b c nb-2 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-2 (pubk b)))
      (send (enc a b d nb-2 nb-2 (pubk c))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-2 nb-2 (pubk c)))
      (send (enc a b c nb-2 nb-2 nc-3 (pubk d)))))
  (label 436)
  (parent 163)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (2 0)
    (enc a b c nb-1 nb-1 nc-1 (pubk d))
    (enc a b c nb-1 nb-2 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a b d nb-1 nb-2 (pubk c)) (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-2 (pubk c))))
    ((recv (enc a b d nb-1 nb-2 (pubk c)))
      (send (enc a b c nb-1 nb-2 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 437)
  (parent 163)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-2) (nc nc-2) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-2 nc-2 (pubk d)))
      (send (enc b c d na nb-2 nc-2 nd-0 (pubk a)))))
  (label 438)
  (parent 163)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nd-0 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-1) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (0 1)) ((2 1) (0 1)) ((3 1) (4 0)) ((4 1) (2 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (2 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (2 0)
    (enc a b c na nb-1 nc-1 (pubk d)) (enc a b c na nb-2 nc-2 (pubk d))
    (enc a b d na nb-1 (pubk c)) (enc a b d na nb-2 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-2 (pubk c))))
    ((recv (enc a b d na nb-2 (pubk c)))
      (send (enc a b c na nb-2 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-1 (pubk d)))
      (send (enc b c d na nb-1 nc-1 nd-0 (pubk a)))))
  (label 439)
  (parent 163)
  (unrealized (0 1) (2 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nb-2 nc-1 nb-3 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 477)
  (parent 175)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 nb-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-3) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (3 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (0 1))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-3 (pubk c)))))
  (label 526)
  (parent 192)
  (unrealized (0 1) (4 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nb-1 nc-1 nb-2 nc-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 579)
  (parent 209)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-2 (pubk d)))))
  (label 589)
  (parent 216)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nd-1 nb-1 nc-2 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (6 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (4 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (5 0)
    (enc a b d na nb-1 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d)))))
  (label 603)
  (parent 222)
  (unrealized (0 1) (3 0) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nc-0 nd-0 nc-1 nb-0 nd-1 nb-1 text) (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp1 2) na (6 0)
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b c na nb-0 nc-1 (pubk d)))
      (send (enc b c d na nb-0 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d na (pubk b)))
      (send (enc a b d na nb-1 (pubk c)))))
  (label 615)
  (parent 226)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (6 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (4 0)) ((6 1) (4 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp2 2) na (6 0)
    (enc a b d na nb-0 (pubk c)) (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-3 (pubk d)))))
  (label 618)
  (parent 227)
  (unrealized (0 1) (3 0) (6 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nc-3 text)
    (a b c d name))
  (defstrand init 3 (na nb-1) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-1) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-1) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-1) (nb nb-1) (nc nc-3) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-1)
  (operation nonce-test (added-strand resp2 2) nb-1 (4 0)
    (enc a b c nb-1 nb-1 nc-2 (pubk d)) (enc a b d nb-1 nb-1 (pubk c))
    (enc a c d nb-1 (pubk b)))
  (traces
    ((send (enc a c d nb-1 (pubk b)))
      (recv (enc b c d nb-1 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-0 (pubk c))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-1 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-1 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d nb-1 nb-0 (pubk c)))
      (send (enc a b c nb-1 nb-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-1 (pubk b)))
      (send (enc a b d nb-1 nb-1 (pubk c))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-2 (pubk d))))
    ((recv (enc a b d nb-1 nb-1 (pubk c)))
      (send (enc a b c nb-1 nb-1 nc-3 (pubk d)))))
  (label 621)
  (parent 228)
  (unrealized (0 1) (3 0) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (na nb nc nd nb-0 nc-0 nd-0 nc-1 nb-1 nc-2 nd-1 text)
    (a b c d name))
  (defstrand init 3 (na na) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na na) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na na) (nb nb-1) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na na) (nb nb-1) (nc nc-2) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (5 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (6 0)) ((6 1) (4 0)) ((7 1) (4 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig na)
  (operation nonce-test (added-strand resp3 2) na (4 0)
    (enc a b c na nb-1 nc-2 (pubk d)) (enc a b d na nb-1 (pubk c))
    (enc a c d na (pubk b)))
  (traces
    ((send (enc a c d na (pubk b)))
      (recv (enc b c d na nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-0 (pubk c))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-0 (pubk d))))
    ((recv (enc a b c na nb-0 nc-0 (pubk d)))
      (send (enc b c d na nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a b d na nb-0 (pubk c)))
      (send (enc a b c na nb-0 nc-1 (pubk d))))
    ((recv (enc a c d na (pubk b))) (send (enc a b d na nb-1 (pubk c))))
    ((recv (enc a b d na nb-1 (pubk c)))
      (send (enc a b c na nb-1 nc-2 (pubk d))))
    ((recv (enc a b c na nb-1 nc-2 (pubk d)))
      (send (enc b c d na nb-1 nc-2 nd-1 (pubk a)))))
  (label 622)
  (parent 228)
  (unrealized (0 1) (3 0) (4 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (5 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (3 0)) ((6 1) (5 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 632)
  (parent 232)
  (unrealized (0 1) (3 0) (5 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nc-2 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-2) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-2 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 649)
  (parent 235)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nd-1 nb-2 text)
    (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-1) (nc nc-1) (nd nd-1) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (7 0)) ((1 1) (2 0))
    ((1 1) (3 0)) ((2 1) (0 1)) ((3 1) (0 1)) ((4 1) (5 0))
    ((5 1) (3 0)) ((6 1) (3 0)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a b c nb-0 nb-1 nc-1 (pubk d)))
      (send (enc b c d nb-0 nb-1 nc-1 nd-1 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 652)
  (parent 236)
  (unrealized (0 1) (3 0) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 657)
  (parent 239)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 661)
  (parent 240)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-1) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-1 (pubk c)))
      (send (enc a b c nb-0 nb-1 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 665)
  (parent 241)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nc-1 nb-2 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nc-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nc-0) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (5 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (0 1)) ((7 1) (6 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp1 2) nb-0 (6 0)
    (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nc-0 (pubk c))))
    ((recv (enc a b d nb-0 nc-0 (pubk c)))
      (send (enc a b c nb-0 nc-0 nc-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c)))))
  (label 669)
  (parent 242)
  (unrealized (0 1) (6 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-1) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-1 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 682)
  (parent 246)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nc-0 nd-0 nb-1 nb-2 nc-1 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nc-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-1) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nc-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nc-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nc-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-1 (pubk d)))))
  (label 691)
  (parent 249)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))

(defskeleton nsl4cm
  (vars (nb nc nd nb-0 nd-0 nb-1 nb-2 nc-0 text) (a b c d name))
  (defstrand init 3 (na nb-0) (nb nb) (nc nc) (nd nd) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-0) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nb-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp3 2 (na nb-0) (nb nb-0) (nc nb-0) (nd nd-0) (a a) (b b)
    (c c) (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-1) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-0) (nc nd-0) (a a) (b b) (c c)
    (d d))
  (defstrand resp1 2 (na nb-0) (nb nb-2) (a a) (b b) (c c) (d d))
  (defstrand resp2 2 (na nb-0) (nb nb-2) (nc nc-0) (a a) (b b) (c c)
    (d d))
  (precedes ((0 0) (1 0)) ((0 0) (4 0)) ((0 0) (6 0)) ((0 0) (7 0))
    ((1 1) (2 0)) ((2 1) (3 0)) ((3 1) (0 1)) ((4 1) (3 0))
    ((5 1) (0 1)) ((6 1) (5 0)) ((7 1) (5 0)))
  (non-orig (privk a) (privk b) (privk c) (privk d))
  (uniq-orig nb-0)
  (operation nonce-test (added-strand resp2 2) nb-0 (5 0)
    (enc a b d nb-0 nb-2 (pubk c)) (enc a c d nb-0 (pubk b)))
  (traces
    ((send (enc a c d nb-0 (pubk b)))
      (recv (enc b c d nb-0 nb nc nd (pubk a)))
      (send (enc nb nc nd (pubk b))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-0 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nb-0 (pubk d))))
    ((recv (enc a b c nb-0 nb-0 nb-0 (pubk d)))
      (send (enc b c d nb-0 nb-0 nb-0 nd-0 (pubk a))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-1 (pubk c))))
    ((recv (enc a b d nb-0 nb-0 (pubk c)))
      (send (enc a b c nb-0 nb-0 nd-0 (pubk d))))
    ((recv (enc a c d nb-0 (pubk b)))
      (send (enc a b d nb-0 nb-2 (pubk c))))
    ((recv (enc a b d nb-0 nb-2 (pubk c)))
      (send (enc a b c nb-0 nb-2 nc-0 (pubk d)))))
  (label 705)
  (parent 252)
  (unrealized (0 1) (5 0) (7 0))
  (comment "aborted"))
